Models - The iPhone Wiki

# Models

From The iPhone Wiki

iOS runs on various different models of devices. This page is used to give an overview of the different model numbers (or "M" numbers) used by devices. The model number of your device is located in the Settings app on the "General -> About" screen under "Model".

## Format

The model number of a device begins with a variable first letter representing the source of the device (replacement, engraved, etc.; see below). This is followed by four characters between either "A" and "Z" or "0" and "9" (most commonly only digits). Afterwards is either one or two characters representing the "region" of the device's origin. Depending on the software displaying the string, there may be a slash ("`/`") followed by a character.

### First Letter

  Main article: Model Regions

The first letter in the model number represents the source of the device. Currently, there are four known possible choices:

- "`F`": refurbished unit
- "`M`": retail unit
- "`N`": replacement unit
- "`P`": personalized (engraved) unit

## Finding Your Device

To make searching this page easier, the first letter is always "`M`" and the "region" portion and everything after is removed (leaving us with the first five characters of the string). For example, let's say our model number is "`MC922LL/A`". The first letter is already "`M`", so we leave it alone. Next, we remove the "region" portion and everything after (the "`LL/A`" at the end) leaving us with "`MC922`". A "find-in-page" reveals this is a black 16 GiB iPhone 4S.

If your device is not listed here, please add it yourself or contact an active user.

## AirPods

Generation | "A" Number | Bootrom | FCC ID | Internal Name | Identifier | Color | Model
--- | --- | --- | --- | --- | --- | --- | ---
AirPods (1st generation) | A1523 (right AirPod) A1722 (left AirPod) A1602 (charging case) | Unknown | BCG-A1523 BCG-A1722 | B188AP | AirPods1,1 | N/A | MMEF2
AirPods (2nd generation) | A2031 (left AirPod) A2032 (right AirPod) A1938 (wireless charging case) | Unknown | BCG-A2031 BCG-A2032 | B288AP | AirPods1,2 AirPods2,1 | N/A | MRXJ2, MV7N2, MR8U2
AirPods (3rd generation) | A2564 (left AirPod) A2565 (right AirPod) A2566 (MagSafe charging case) | Unknown | BCG-A2564 BCG-A2565 | B688AP | AirPods1,3 Audio2,1 | N/A | MME73, MPNY3
AirPods Pro | A2083 (left AirPod) A2084 (right AirPod) A2190 (AirPods Pro/MagSafe charging case) | Unknown | BCG-A2083 BCG-A2084 | B298AP | AirPods2,2 AirPodsPro1,1 iProd8,1 | N/A | MWP22, MLWK3
AirPods Pro (2nd generation) | A2699 (left AirPod) A2698 (right AirPod) A2700 (charging case) | Unknown | BCG-A2698 BCG-A2699 | B698AP | AirPodsPro1,2 | N/A | MQD83
AirPods Max | A2096 | Unknown | BCG-A2096 | B515AP | AirPodsMax1,1 iProd8,6 | Space Grey | MGYH3
Pink | MGYM3
Silver | MGYJ3
Green | MGYN3
Sky Blue | MGYL3

## AirTag

Generation | "A" Number | Bootrom | FCC ID | Internal Name | Identifier | Pack Size | Model
--- | --- | --- | --- | --- | --- | --- | ---
AirTag | A2187 | Unknown | BCGA2187 | B389AP | AirTag1,1 | 1 pack | MX532
4 pack | MX542

## Apple TV

Generation | "A" Number | Bootrom | FCC ID | Internal Name | Identifier | Color | Storage | Model
--- | --- | --- | --- | --- | --- | --- | --- | ---
Apple TV (1st generation) | A1218 | None | Unknown | Unknown | AppleTV1,1 | Silver | 40 GB | MA711
160 GB | MB189
Apple TV (2nd generation) | A1378 | Bootrom 574.4 | BCGA1378 | K66AP | AppleTV2,1 | Black | 8 GB | MC572
Apple TV (3rd generation) | A1427 | ROM | BCGA1427 | J33AP | AppleTV3,1 | Black | 8 GB | MD199
A1469 | Bootrom 1458.2 | BCGA1469 | J33IAP | AppleTV3,2 | Black | 8 GB
Apple TV (4th generation) | A1625 | Bootrom 1992.0.0.1.19 | BCGA1625 | J42dAP | AppleTV5,3 | Black | 32 GB | MGY52, ML4W2, MR912
64 GB | MLNC2
Apple TV 4K | A1842 | Bootrom 3135.0.0.2.3 | BCGA1842 | J105aAP | AppleTV6,2 | Black | 32 GB | MQD22
64 GB | MP7P2
Apple TV 4K (2nd generation) | A2169 | Bootrom 3865.0.0.4.7 | BCGA2169 | J305AP | AppleTV11,1 | Black | 32 GB | MXGY2
64 GB | MXH02

### Siri Remote

Generation | "A" Number | FCC ID | Internal Name | Identifier | Model
--- | --- | --- | --- | --- | ---
Siri Remote | A1513 | BCGA1513 | B239AP | Unknown | MLLC2
Siri Remote (Rev A) | A1962 | BCGA1962 | B439AP | Unknown | MQGD2
Siri Remote (2nd generation) | A2540 | BCGA2540 | Unknown | Unknown | MJFM3

## Apple Watch

Generation | "A" Number | Bootrom | FCC ID | Internal Name | Identifier | Case Material | Finish | Case Size | Model
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
Apple Watch (1st generation) | A1553 | Bootrom 2098.0.0.2.4 | BCG-E2870 | N27aAP | Watch1,1 | Aluminium | Gold | 38mm | MLCJ2, MMEC2, MMF52
Rose Gold | MLCH2, MMF42
Silver | MJ2T2, MJ2U2, MJ2V2, MJ2W2, MLCF2, MLCG2, MME92, MMF02, MMF12, MMF22, MMF32
Space Gray | MJ2X2, MMF62
Stainless Steel | Silver | MJ2Y2, MJ3A2, MJ3E2, MJ302, MJ312, MJ322, MJ332, MJ362, MJYK2, MLCL2, MLCN2, MLCP2, MLC02, MLC22, MLC32, MLE62, MLLD2, MMF82, MMFD2, MMF92, MMFH2, MMFK2
Space Black | MJ3F2, MLCK2
Gold | Rose Gold | MJ3K2, MJ3L2, MJ8P2
Yellow Gold | MJ3G2, MKL52
A1554 A1638 | BCG-E2871 | N28aAP | Watch1,2 | Aluminium | Gold | 42mm | MLC72, MMEE2, MMFQ2
Rose Gold | MLC62, MMFP2
Silver | MJ3N2, MJ3P2, MJ3Q2, MJ3R2, MLC42, MLC52, MMED2, MMFE2, MMFL2, MMFM2, MMFN2
Space Gray | MJ3T2, MMFR2
Stainless Steel | Silver | MJ3U2, MJ3V2, MJ3X2, MJ3Y2, MJ402, MJ432, MJ452, MJ472, MJYN2, MLCC2, MLCD2, MLCE2, MLC92, MLFA2, MLFC2, MLLE2, MMFU2, MMFV2, MMFX2, MMG02
Space Black | MJ482, MLC82, MMG22
Gold | Rose Gold | MJ4A2, MLE52
Yellow Gold | MJ8Q2, MJVT2, MKL62, MLFH2
Apple Watch Series 1 | A1802 | Bootrom 2651.0.0.1.31 | BCG-E3102 | N27dAP | Watch2,6 | Aluminium | Gold | 38mm | MNNJ2, MQ102
Rose Gold | MNNH2
Silver | MNNG2
Space Gray | MP022
A1803 | BCG-E3103 | N28dAP | Watch2,7 | Gold | 42mm | MNNN2, MQ122
Rose Gold | MNNM2, MQ112
Silver | MNNL2
Space Gray | MP032
Apple Watch Series 2 | A1757 A1816 | Bootrom 2651.0.0.1.31 | BCG-E3104 | N74AP | Watch2,3 | Aluminium | Gold | 38mm | MNP22, MNP32, MQ132
Rose Gold | MNNY2, MNP02
Silver | MNNQ2, MNNW2, MNNX2, MNYP2, MQ172
Space Gray | MNYX2, MP0D2, MP052, MP082, MQ162
Stainless Steel | Silver | MNP42, MNP52, MNP62, MNP72, MNP82, MNP92, MNPA2, MNQ52, MNQ62, MNQ72, MNQ82, MNQ92, MQ1F2
Space Black | MNPD2, MNPE2, MP492
Ceramic | White | MNPF2
A1758 A1817 | BCG-E3105 | N75AP | Watch2,4 | Aluminium | Gold | 42mm | MNPN2, MNPP2, MQ152
Rose Gold | MNPL2, MNPM2, MQ142
Silver | MNNT2, MNPJ2, MNPK2, MNYQ2, MQ192
Space Gray | MNYY2, MP0A2, MP062, MP072, MQ182
Stainless Steel | Silver | MNPR2, MNPT2, MNPU2, MNPV2, MNPW2, MNQ02, MNQ22, MNQ32, MNQC2
Space Black | MNQ12, MP4A2
Ceramic | White | MNPQ2
Apple Watch Series 3 | A1860 A1889 A1890 | Bootrom 2651.0.0.3.3 | BCG-A1860 BCG-A1889 BCG-A1890 | N111sAP | Watch3,1 | Aluminium | Gold | 38mm | MQJQ2, MQJU2, MQKH2, MQKL2, MQQG2, MQQK2
Silver | MQJN2, MQJR2, MQKF2, MQKJ2, MQL52, MQL72, MQM72, MQM92, MQQE2, MQQH2, MQR42, MQR62
Space Gray | MQJP2, MQJT2, MQKK2, MQKN2, MQL62, MQL82, MQM82, MQMA2, MR2W2, MR2Y2, MR332, MQQF2, MQQJ2, MQR52, MQR72
Stainless Steel | Silver | MQJV2, MQLJ2, MQLK2, MQLM2, MQLN2, MQLV2, MQML2, MQMM2, MQMP2, MQMQ2, MQQL2, MQRA2, MQRE2, MQRF2, MQX92, MR1F2. MR1N2, MR212
Space Black | MQJW2, MQLW2, MQQM2, MR1H2, MR1Q2, MR222
Ceramic | White | MQJY2, MQM32, MQQP2
Gray | MQK02, MQM42, MQQQ2
A1861 A1891 A1892 | BCG-A1861 BCG-A1891 BCG-A1892 | N111bAP | Watch3,2 | Aluminium | Gold | 42mm | MQK32, MQK72, MQKP2, MQKT2, MQQU2, MQQX2
Silver | MQK12, MQK52, MQKM2, MQKQ2, MQLC2, MQLE2, MQME2, MQMG2, MQQR2, MQQV2, MQRG2, MQRJ2
Space Gray | MQK22, MQK62, MQKN2, MQKR2, MQLD2, MQLF2, MQMF2, MQMH2, MQQT2, MQQW2, MR2X2, MR302, MR342, MQRH2, MQRK2
Stainless Steel | Silver | MQK82, MQLP2, MQLQ2, MQLR2, MQLT2, MQLU2, MQLY2, MQMR2, MQMT2, MQMU2, MQMV2, MQMW2, MQQY2, MQRN2, MQRP2, MQRQ2, MQRR2, MQRT2, MQX62, MQX72, MQX92, MR1J2, MR1U2, MR232
Space Black | MQK92, MQM02, MQR02, MR1L2, MR1V2, MR242
Ceramic | White | MQKD2, MQM52, MQR22
Gray | MQKE2, MQM62, MQR32
A1858 | BCG-A1858 | N121sAP | Watch3,3 | Aluminium | Gold | 38mm | MQKW2
Silver | MQKU2, MQKX2
Space Gray | MQKV2, MQKY2, MR352
A1859 | BCG-A1859 | N121bAP | Watch3,4 | Aluminium | Gold | 42mm | MQL22
Silver | MQL02, MQL32
Space Gray | MQL12, MQL42, MR362
Apple Watch Series 4 | A1977 | Bootrom 3988.0.0.2.12 | BCG-A1977 | N131sAP | Watch4,1 | Aluminium | Gold | 40mm | MU682, MU692
Silver | MU642, MU652, MU6H2, MU7F2
Space Gray | MU662, MU672, MU6J2, MU7G2
A1978 | BCG-A1978 | N131bAP | Watch4,2 | Aluminium | Gold | 44mm | MU6F2, MU6G2
Silver | MU6A2, MU6C2, MU6K2, MU7H2
Space Gray | MU6D2, MU6E2, MU6L2, MU7J2
A1975 A2007 | BCG-A1975 BCG-A2007 | N141sAP | Watch4,3 | Aluminium | Gold | 40mm | MTUJ2, MTUK2, MTVG2, MTVH2
Silver | MTUD2, MTUF2, MTV92, MTX72, MTVA2, MTVC2, MTX62, MTXF2
Space Gray | MTUG2, MTUN2, MTX82, MTX92, MTVD2, MTVF2, MTXG2, MTXH2
Stainless Steel | Gold | MTUR2, MTUT2, MTVN2, MTVQ2
Silver | MTUL2, MTUM2, MU7K2, MU6R2, MU6N2, MU6Q2, MU6P2, MU6M2, MTVJ2, MTVK2, MU7L2, MU732, MU702, MU722, MU712, MU6Y2
Space Black | MTUN2, MTUQ2, MTVL2, MTVM2
A1976 A2008 | BCG‑A1976 BCG-A2008 | N141bAP | Watch4,4 | Aluminium | Gold | 44mm | MTV02, MTV12, MTVW2, MTVX2
Silver | MTUU2, MTUV2, MU6X2, MTXC2, MTXA2, MTVR2, MTVT2, MTXK2, MTXJ2
Space Gray | MTUW2, MTUX2, MTXE2, MTXD2, MTVU2, MTVV2, MTXM2, MTXL2
Stainless Steel | Gold | MTV72, MTV82, MTX42, MTX52
Silver | MTV22, MTV42, MU6W2, MU6V2, MU9D2, MU9D2, MU6U2, MU6T2, MU782, MU772, MU762, MU9E2, MU752, MU742
Space Black | MTV52, MTV62, MTX22, MTX32
Apple Watch Series 5 | A2092 | Bootrom 3988.0.0.2.12 | BCG-A2092 | N144sAP | Watch5,1 | Aluminium | Gold | 40mm | MWRY2, MWV72
Silver | MWRX2, MX3R2, MWV62
Space Gray | MWT02, MWV82
A2093 | BCG-A2093 | N144bAP | Watch5,2 | Aluminium | Gold | 44mm | MWT42
Silver | MWVD2, MX3V2, MWT62, MWT32
Space Gray | MWT52, MWVF2, MWT72
A2094 A2156 | BCG-A2094 BCG-A2156 | N146sAP | Watch5,3 | Aluminium | Gold | 40mm | MWPU2, MWQ72
Silver | MWWN2, MWX12, MX372, MX3C2, MWPT2, MWQ62, MWQG2
Space Gray | MWPV2, MWQ82, MWWQ2, MWX32, MWQ42, MWQH2
Stainless Steel | Gold | MWPW2, MWX62, MWWV2, MWWU2
Stainless Steel | MWPX2, MWQA2, MX5L2, MX5K2, MWWT2, MWX52, MWQJ2, MX5M2, MX5N2
Space Black | MWPY2, MWQC2, MWX02, MWXC2, MWXA2
Titanium | Titanium | MWQ12, MWQE2
Space Black | MWQ02, MWQD2
Ceramic | White | MWQ22, MWQF2
A2095 A2157 | BCG-A2095 BCG-A2157 | N146bAP | Watch5,4 | Aluminium | Gold | 44mm | MWQL2, MWR02
Silver | MWVY2, MWWC2, MX392, MX3E2, MWQV2, MXR12, MWQK2, MWQY2, MWR82
Space Gray | MWQM2, MWR12, MWW12, MWWE2, MWQW2, MX3A2, MWR92
Stainless Steel | Gold | MWQN2, MWWH2, MWW62, MWW52, MWR22, MWWJ2
Stainless Steel | MWQP2, MWR32, MWQX2, MWW32, MWWG2, MWRA2, MX5C2
Space Black | MWQQ2, MWR42, MWW92, MWWM2
Titanium | Titanium | MWQT2, MWR62
Space Black | MWQR2, MWR52
Ceramic | White | MWQU2, MWR72
Apple Watch SE | A2351 | ? | BCG-A2351 | N140sAP | Watch5,9 | Aluminium | Gold | 40mm | MYDY2
Silver | MYDX2
Space Gray | MYE02
A2352 | BCG-A2352 | N140bAP | Watch5,10 | Gold | 44mm | MYE22
Silver | MYE12
Space Gray | MYE32
A2353 A2355 | BCG-A2353 BCG-A2355 | N142sAP | Watch5,11 | Gold | 40mm | MYF32, MYF62
Silver | MYF22, MYF52
Space Gray | MYF42, MYF72
A2354 A2356 | BCG-A2353 BCG-A2355 | N142bAP | Watch5,12 | Gold | 44mm | MYF92, MYFD2
Silver | MYF82, MYFC2
Space Gray | MYFA2, MYFE2
Apple Watch Series 6 | A2291 | ? | BCG-A2292 | N157sAP | Watch6,1 | Aluminium | Gold | 40mm | MG193
Silver | MG183
Space Gray | MG1A3
Blue | MG2A3
PRODUCT(RED) | M02C3
A2292 | BCG-A2292 | N157bAP | Watch6,2 | Gold | 44mm | M02E3
Silver | M02D3
Space Gray | M02F3
Blue | M02G3
PRODUCT(RED) | M02H3
A2293 A2375 | BCG-A2293 BCG-A2375 | N158sAP | Watch6,3 | Aluminium | Gold | 40mm | M0DP3, M0D53
Silver | M0DM3, M0D23
Space Gray | M0DQ3, M0D63
Blue | M0DR3, M0D73
PRODUCT(RED) | M0DT3, M0D83
Stainless Steel | Gold | M0DU3, M0D93
Silver | M0DV3, M0DC3
Graphite | M0DW3, M0DF3
Space Black | MG363, MG303
Titanium | Titanium | M0DY3, M0DH3
Space Black | M0DX3, M0DG3
A2294 A2376 | BCG-A2294 BCG-A2376 | N158bAP | Watch6,4 | Aluminium | Gold | 44mm | M0GQ3, M0G73
Silver | M0GP3, M0G63
Space Gray | M0GR3, M0G83
Blue | M0GT3, M0G93
PRODUCT(RED) | M0GU3, M0GC3
Stainless Steel | Gold | M0GV3, M0GD3
Silver | M0GW3, M0GF3
Graphite | M0GX3, M0GG3
Titanium | Titanium | M0H23, M0GJ3
Space Black | M0H13, M0GH3
Apple Watch Series 7 | A2473 | ? | BCG-A2473 | N187sAP | Watch6,6 | Aluminium | Green | 41mm | MKNF3
Starlight | MKNP3
Midnight | MKMX3
Blue | MKNH3
PRODUCT(RED) | MKNJ3
A2474 | BCG-A2474 | N187bAP | Watch6,7 | Green | 45mm | MKNQ3
Starlight | MKNP3
Midnight | MKN53
Blue | MKNR3
PRODUCT(RED) | MKNT3
A2475 A2476 | BCG-A2475 BCG-A2476 | N188sAP | Watch6,8 | Aluminium | Green | 41mm | MKLA3, MKLP3
Starlight | MKL93, MKLN3
Midnight | MKH73, MKHQ3
Blue | MKLC3, MKLQ3
PRODUCT(RED) | MKLD3, MKLR3
Stainless Steel | Gold | MKLE3, MKLT3
Silver | MKLF3, MKHX3
Graphite | MKHK3, MKJ23
Space Black | MKLL3, MKM23
Titanium | Titanium | ML8U3, ML913
Space Black | ML8V3, ML903
A2477 A2478 | BCG-A2477 BCG-A2478 | N188bAP | Watch6,9 | Aluminium | Green | 45mm | MKM63, MKML3
Starlight | MKM53, MKMK3
Midnight | MKJ73, MKJP3
Blue | MKM73, MKMM3
PRODUCT(RED) | MKM83, MKMN3
Stainless Steel | Gold | MKM93, ML7W3
Silver | MKJE3, MKJW3
Graphite | MKJJ3, MKL33
Space Black | MKMH3, MKMW3
Titanium | Titanium | ML8W3, ML8Y3
Space Black | ML8V3, ML8X3
SE (2nd generation) | ? | ? | ? | N143sAP | Watch6,10 | Aluminum | Midnight | 41mm | ?
Starlight | ?
Silver | ?
N143bAP | Watch6,11 | Aluminum | Midnight | 45mm | ?
Starlight | ?
Silver | ?
N149sAP | Watch6,12 | Aluminum | Midnight | 41mm | ?
Starlight | ?
Silver | ?
N149bAP | Watch6,13 | Aluminum | Midnight | 45mm | ?
Starlight | ?
Silver | ?
Apple Watch Series 8 | ? | ? | ? | ? | Watch6,14 | Aluminum | Midnight | 41mm | ?
Starlight | ?
Silver | ?
(PRODUCT)RED | ?
Stainless Steel | Gold | ?
Silver | ?
Graphite | ?
Space Black | ?
? | Watch6,15 | Aluminum | Midnight | 45mm | ?
Starlight | ?
Silver | ?
(PRODUCT)RED | ?
Stainless Steel | Gold | ?
Silver | ?
Graphite | ?
Space Black | ?
? | Watch6,16 | Aluminum | Midnight | 41mm | ?
Starlight | ?
Silver | ?
(PRODUCT)RED | ?
Stainless Steel | Gold | ?
Silver | ?
Graphite | ?
Space Black | ?
? | Watch6,17 | Aluminum | Midnight | 45mm | ?
Starlight | ?
Silver | ?
(PRODUCT)RED | ?
Stainless Steel | Gold | ?
Silver | ?
Graphite | ?
Space Black | ?
Apple Watch Ultra | ? | ? | ? | N199AP | Watch6,18 | Titanium | 49mm | MQFY3, MQG03, MQG13

## HomePod

Generation | "A" Number | Bootrom | FCC ID | Internal Name | Identifier | Color | Model
--- | --- | --- | --- | --- | --- | --- | ---
HomePod | A1639 | Bootrom 1992.0.0.1.19 | BCG-A1639 | B238aAP | AudioAccessory1,1 | Space Gray | MQHW2
White | MQHV2
Unknown | Bootrom 1992.0.0.1.19 | Unknown | B238AP | AudioAccessory1,2 | Space Gray | Unknown
White | Unknown
HomePod mini | A2374 | Bootrom 3988.0.0.2.12 | BCG-A2374 | B520AP | AudioAccessory5,1 | Space Gray | MY5G2
White | MY5H2

## iPad

Generation | "A" Number | Bootrom | FCC ID | Internal Name | Identifier | Finish | Storage | Model
--- | --- | --- | --- | --- | --- | --- | --- | ---
iPad | A1219 | Bootrom 574.4 | BCG-E2381A | K48AP | iPad1,1 | Black | 16 GB | MB292
32 GB | MB293
64 GB | MB294
A1337 | BCG-E2328A | 16 GB | MC349
32 GB | MC496
64 GB | MC497
iPad 2 | A1395 | Bootrom 838.3 | BCGA1395 | K93AP | iPad2,1 | Black | 16 GB | MC769
32 GB | MC770
64 GB | MC916
White | 16 GB | MC979, MD002
32 GB | MC980
64 GB | MC981
A1396 | BCGA1396 | K94AP | iPad2,2 | Black | 16 GB | MC773, MC957
32 GB | MC774
64 GB | MC775
White | 16 GB | MC982, MC992
32 GB | MC983
64 GB | MC984
A1397 | BCGA1397 | K95AP | iPad2,3 | Black | 16 GB | MC755
32 GB | MC763
64 GB | MC764
White | 16 GB | MC985
32 GB | MC986
64 GB | MC987
A1395 | ROM | BCGA1395 | K93AAP | iPad2,4 | Black | 16 GB | MC954, MC960, MC988
White | 16 GB | MC989
iPad (3rd generation) | A1416 | Bootrom 1062.2 | BCGA1416 | J1AP | iPad3,1 | Black | 16 GB | MC705, MD333
32 GB | MC706, MD334
64 GB | MC707, MD335
White | 16 GB | MD328, MD336
32 GB | MD329, MD337
64 GB | MD330, MD338
A1403 | BCGA1403 | J2AP | iPad3,2 | Black | 16 GB | MC733
32 GB | MC744
64 GB | MC756
White | 16 GB | MD363
32 GB | MD364
64 GB | MD365
A1430 | BCGA1430 | J2AAP | iPad3,3 | Black | 16 GB | MD366, MD404
32 GB | MD367, MD405
64 GB | MD368, MD406
White | 16 GB | MD369, MD407
32 GB | MD370, MD408
64 GB | MD371, MD409
iPad (4th generation) | A1458 | Bootrom 1145.3.3 | BCGA1458 | P101AP | iPad3,4 | Black | 16 GB | MD510
32 GB | MD511
64 GB | MD512
128 GB | ME392
White | 16 GB | MD513
32 GB | MD514
64 GB | MD515
128 GB | ME393
A1459 | BCGA1459 | P102AP | iPad3,5 | Black | 16 GB | MD516, MG932
32 GB | MD517
64 GB | MD518, MD944
128 GB | ME400
White | 16 GB | MD519, MG942
32 GB | MD520
64 GB | MD521
128 GB | ME401
A1460 | BCGA1460 | P103AP | iPad3,6 | Black | 16 GB | MD522, ME195
32 GB | MD523, ME196
64 GB | MD524, ME197
128 GB | ME406, ME410
White | 16 GB | MD525, ME198
32 GB | MD526, ME199
64 GB | MD527, ME200
128 GB | ME407, ME411
iPad (5th generation) | A1822 | Bootrom 2234.0.0.3.3 | BCGA1822 | J71sAP J71tAP | iPad6,11 | Gold | 32 GB | MPGT2
128 GB | MPGW2
Silver | 32 GB | MP2G2
128 GB | MP2J2
Space Gray | 32 GB | MP2F2
128 GB | MP2H2
A1823 | BCGA1823 | J72sAP J72tAP | iPad6,12 | Gold | 32 GB | MPG42, MPGA2
128 GB | MPG52, MPGC2
Silver | 32 GB | MP1L2, MP252
128 GB | MP272, MP2E2
Space Gray | 32 GB | MP1J2, MP242
128 GB | MP262, MP2D2
iPad (6th generation) | A1893 | Bootrom 2696.0.0.1.33 | BCGA1893 | J71bAP | iPad7,5 | Gold | 32 GB | MRJN2
128 GB | MRJP2
Silver | 32 GB | MR7G2
128 GB | MR7K2
Space Gray | 32 GB | MR7F2
128 GB | MR7J2
A1954 | BCGA1954 | J72bAP | iPad7,6 | Gold | 32 GB | MRM52
128 GB | MRM82
Silver | 32 GB | MR702
128 GB | MR7D2
Space Gray | 32 GB | MR6Y2
128 GB | MR7C2
iPad (7th generation) | A2197 | Bootrom 2696.0.0.1.33 | BCGA2197 | J171AP | iPad7,11 | Gold | 32 GB | MW762
128 GB | MW792
Silver | 32 GB | MW752
128 GB | MW782
Space Gray | 32 GB | MW742
128 GB | MW772
A2198 A2200 | BCGA2198 BCGA2200 | J172AP | iPad7,12 | Gold | 32 GB | MW6D2, MW6R2, MW6Y2
128 GB | MW6G2, MW6V2, MW722
Silver | 32 GB | MW6C2, MW6Q2, MW6X2
128 GB | MW6F2, MW6U2, MW712
Space Gray | 32 GB | MW6A2, MW6P2, MW6W2
128 GB | MW6E2, MW6T2, MW702
iPad (8th generation) | A2270 | ? | BCGA2270 | J171aAP | iPad11,6 | Gold | 32 GB | MYLC2
128 GB | MYLF2
Silver | 32 GB | MYLA2
128 GB | MYLE2
Space Gray | 32 GB | MYL92
128 GB | MYLD2
A2428 A2429 A2430 | BCGA2428 BCGA2429 | J172aAP | iPad11,7 | Gold | 32 GB | MYMK2, MYN62
128 GB | MYMN2, MYN92
Silver | 32 GB | MYMJ2, MYN52
128 GB | MYMM2, MYN82
Space Gray | 32 GB | MYMH2, MYN32
128 GB | MYML2, MYN72
iPad (9th generation) | A2602 | ? | ? | J181AP | iPad12,1 | Silver | 64 GB | MK2L3
256 GB | MK2P3
Space Gray | 64 GB | MK2K3
256 GB | MK2N3
A2603 A2604 A2605 | BCGA2603 BCGA2604 BCGA2605 | J182AP | iPad12,2 | Silver | 64 GB | MK493, MK673
256 GB | MK4H3, MK6A3
Space Gray | 64 GB | MK473, MK663
256 GB | MK4E3, MK693
iPad (10th generation) | A2696 | ? | BCGA2696 | J271AP | iPad13,18 | Yellow | 64 GB | MPQ23
256 GB | MPQA3
Silver | 64 GB | MPQ03
256 GB | MPQ83
Blue | 64 GB | MPQ13
256 GB | MPQ93
Pink | 64 GB | MPQ33
256 GB | MPQC3
A2757 | BCGA2757 | J272AP | iPad13,19 | Yellow | 64 GB | MQ6V3
256 GB | MQ6L3
Silver | 64 GB | MQ6J3
256 GB | MQ6T3
Blue | 64 GB | MQ6K3
256 GB | MQ6U3
Pink | 64 GB | MQ6M3
256 GB | MQ6W3

### Apple Pencil

Generation | "A" Number | FCC ID | Internal Name | Identifier | Model
--- | --- | --- | --- | --- | ---
Apple Pencil | A1603 | BCGA1603 | B222AP | Unknown | MK0C2
Apple Pencil (2nd generation) | A2051 | BCGA2051 | B332AP | Unknown | MU8F2

### Smart Keyboard

Generation | "A" Number | Internal Name | Identifier | iPad Compatibility | Model
--- | --- | --- | --- | --- | ---
Smart Keyboard | A1636 | B249AP | Unknown | iPad Pro (12.9-inch), iPad Pro (12.9-inch) (2nd generation) | MJYR2, MNKT2
A1772 | iPad Pro (9.7-inch) | MM2L2
A1829 | iPad Pro (10.5-inch), iPad Air (3rd generation) | MPTL2
Smart Keyboard Folio | A2038 | B259AP | Unknown | iPad Pro (11-inch) | MU8G2
A2039 | iPad Pro (12.9-inch) (3rd generation) | MU8H2

## iPad Air

Generation | "A" Number | Bootrom | FCC ID | Internal Name | Identifier | Finish | Storage | Model
--- | --- | --- | --- | --- | --- | --- | --- | ---
iPad Air | A1474 | Bootrom 1704.10 | BCGA1474 | J71AP | iPad4,1 | Silver | 16 GB | MD788
32 GB | MD789
64 GB | MD790
128 GB | ME906
Space Gray | 16 GB | MD785
32 GB | MD786
64 GB | MD787
128 GB | ME898
A1475 | BCGA1475 | J72AP | iPad4,2 | Silver | 16 GB | MD794, ME997, ME999, MF021, MF502
32 GB | MD795, MF025, MF527, MF529, MF532
64 GB | MD796, MF012, MF013, MF027, MF539
128 GB | ME988, MF018, MF019, MF029, MF563
Space Gray | 16 GB | MD791, ME991, ME993, MF020, MF496
32 GB | MD792, MF003, MF004, MF024, MF520
64 GB | MD793, MF009, MF010, MF026, MF534
128 GB | ME987, MF015, MF016, MF028, MF558
A1476 | BCGA1476 | J73AP | iPad4,3 | Silver | 16 GB | MF230
32 GB | MF233
64 GB | MF234
128 GB | MF236
Space Gray | 16 GB | MD797
32 GB | MD798
64 GB | MD799
128 GB | MF235
iPad Air 2 | A1566 | Bootrom 1991.0.0.2.16 | BCGA1566 | J81AP | iPad5,3 | Gold | 16 GB | MH0W2
32 GB | MNV72
64 GB | MH182
128 GB | MH1J2
Silver | 16 GB | MGLW2
32 GB | MNV62
64 GB | MGKM2
128 GB | MGTY2
Space Gray | 16 GB | MGL12
32 GB | MNV22
64 GB | MGKL2
128 GB | MGTX2
A1567 | BCGA1567 | J82AP | iPad5,4 | Gold | 16 GB | MH2W2, MH1C2
32 GB | MNW32
64 GB | MH2P2, MH172, MHWP2
128 GB | MH332, MH2D2, MH1G2
Silver | 16 GB | MH2V2, MGHC2
32 GB | MNW22
64 GB | MH2N2, MGHY2, MGK02
128 GB | MH322, MGWM2
Space Gray | 16 GB | MGGX2, MH2U2, MGH62
32 GB | MNW12
64 GB | MH2M2, MGHX2, MGJY2
128 GB | MH312, MGWL2
iPad Air (3rd generation) | A2152 | Bootrom 3865.0.0.4.7 | BCGA2152 | J217AP | iPad11,3 | Gold | 64 GB | MUUL2
256 GB | MUUT2
Silver | 64 GB | MUUK2
256 GB | MUUR2
Space Gray | 64 GB | MUUJ2
256 GB | MUUQ2
A2123 A2153 A2154 | BCGA2123 BCGA2153 | J218AP | iPad11,4 | Gold | 64 GB | MV172, MV0F2
256 GB | MV1G2, MV0Q2
Silver | 64 GB | MV162, MV0E2
256 GB | MV1F2, MV0P2
Space Gray | 64 GB | MV152, MV0D2
256 GB | MV1D2, MV0N2
iPad Air (4th generation) | A2316 | Bootrom 5281.0.0.100.45 | BCGA2316 | J307AP | iPad13,1 | Rose Gold | 64 GB | MYFP2
256 GB | MYFX2
Silver | 64 GB | MYFN2
256 GB | MYFW2
Space Gray | 64 GB | MYFM2
256 GB | MYFT2
Green | 64 GB | MYFR2
256 GB | MYG02
Sky Blue | 64 GB | MYFQ2
256 GB | MYFY2
A2324 A2325 A2072 | BCGA2324 BCGA2072 | J308AP | iPad13,2 | Rose Gold | 64 GB | MYGY2, MYJ02
256 GB | MYH52, MYJ52
Silver | 64 GB | MYGX2, MYHY2
256 GB | MYH42, MYJ42
Space Gray | 64 GB | MYGW2, MYHX2
256 GB | MYH22, MYJ32
Green | 64 GB | MYH12, MYJ22
256 GB | MYH72, MYJ72
Sky Blue | 64 GB | MYH02, MYJ12
256 GB | MYH62, MYJ62
iPad Air (5th generation) | A2588 | ? | ? | J407AP | iPad13,16 | Space Gray | 64 GB | MM9C3
256 GB | MM9L3
Pink | 64 GB | MM9D3
256 GB | MM9M3
Purple | 64 GB | MME23
256 GB | MME63
Blue | 64 GB | MM9E3
256 GB | MM9N3
Starlight | 64 GB | MM9F3
256 GB | MM9P3
A2589 A2591 | ? | J408AP | iPad13,17 | Space Gray | 64 GB | MM6R3, MM753
256 GB | MM713, MM7E3
Pink | 64 GB | MM6T3, MM9M3
256 GB | MM723, MM7F3
Purple | 64 GB | MME93, MME23
256 GB | MMED3, MME63
Blue | 64 GB | MM6U3, MM773
256 GB | MM733, MM7G3
Starlight | 64 GB | MM6V3, MM783
256 GB | MM743, MM7H3

## iPad Pro

Generation | "A" Number | Bootrom | FCC ID | Internal Name | Identifier | Finish | Storage | Model
--- | --- | --- | --- | --- | --- | --- | --- | ---
iPad Pro (12.9-inch) | A1584 | Bootrom 2481.0.0.2.1‎ | BCGA1584 | J98aAP | iPad6,7 | Gold | 32 GB | ML0H2
128 GB | ML0R2
256 GB | ML0V2
Silver | 32 GB | ML0G2
128 GB | ML0Q2
256 GB | ML0U2
Space Gray | 32 GB | ML0F2
128 GB | ML0N2
256 GB | ML0T2
A1652 | BCGA1652 | J99aAP | iPad6,8 | Gold | 128 GB | ML3Q2, ML2K2, ML3P2
256 GB | ML3Z2, ML2N2, ML412
Silver | 128 GB | ML3N2, ML2J2, ML3O2
256 GB | ML3W2, ML2M2
Space Gray | 128 GB | ML3K2, ML2I2
256 GB | ML3T2, ML2L2
iPad Pro (9.7-inch) | A1673 | Bootrom 2481.0.0.2.1‎ | BCGA1673 | J127AP | iPad6,3 | Gold | 32 GB | MLMQ2
128 GB | MLMX2
256 GB | MLN12
Silver | 32 GB | MLMP2
128 GB | MLMW2
256 GB | MLN02
Space Gray | 32 GB | MLMN2
128 GB | MLMV2
256 GB | MLMY2
Rose Gold | 32 GB | MM172
128 GB | MM192
256 GB | MM1A2
A1674 A1675 | BCGA1674 | J128AP | iPad6,4 | Gold | 32 GB | MLPY2
128 GB | MLQ52
256 GB | MLQ82
Silver | 32 GB | MLPX2
128 GB | MLQ42
256 GB | MLQ72
Space Gray | 32 GB | MLPW2
128 GB | MLQ32
256 GB | MLQ62
Rose Gold | 32 GB | MLYJ2
128 GB | MLYL2
256 GB | MLYM2
iPad Pro (12.9-inch) (2nd generation) | A1670 | Bootrom 3135.0.0.2.3 | BCGA1670 | J120AP | iPad7,1 | Gold | 64 GB | MQDD2
256 GB | MP6J2
512 GB | MPL12
Silver | 64 GB | MQDC2
256 GB | MP6H2
512 GB | MPL02
Space Gray | 64 GB | MQDA2
256 GB | MP6G2
512 GB | MPKY2
A1671 A1821 | BCGA1671 | J121AP | iPad7,2 | Gold | 64 GB | MQEF2
256 GB | MPA62
512 GB | MPLL2
Silver | 64 GB | MQEE2
256 GB | MPA52
512 GB | MPLK2
Space Gray | 64 GB | MQED2
256 GB | MPA42
512 GB | MPLJ2
iPad Pro (10.5-inch) | A1701 | Bootrom 3135.0.0.2.3 | BCGA1701 | J207AP | iPad7,3 | Gold | 64 GB | MQDX2
256 GB | MPF12
512 GB | MPGK2
Rose Gold | 64 GB | MQDY2
256 GB | MPF22
512 GB | MPGL2
Silver | 64 GB | MQDW2
256 GB | MPF02
512 GB | MPGJ2
Space Gray | 64 GB | MQDT2
256 GB | MPDY2
512 GB | MPGH2
A1709 | BCGA1709 | J208AP | iPad7,4 | Gold | 64 GB | MQF12
256 GB | MPHJ2
512 GB | MPMG2
Rose Gold | 64 GB | MQF22
256 GB | MPHK2
512 GB | MPMH2
Silver | 64 GB | MQF02
256 GB | MPHH2
512 GB | MPMF2
Space Gray | 64 GB | MQEY2
256 GB | MPHG2
512 GB | MPME2
iPad Pro (11-inch) | A1980 | Bootrom 4172.0.0.100.14 | BCGA1980 | J317AP | iPad8,1 | Silver | 64 GB | MTXP2
256 GB | MTXR2
512 GB | MTXU2
Space Gray | 64 GB | MTXN2
256 GB | MTXQ2
512 GB | MTXT2
J317xAP | iPad8,2 | Silver | 1 TB | MTXW2
Space Gray | 1 TB | MTXV2
A1934 | BCGA1934 | J318AP | iPad8,3 | Silver | 64 GB | MU0U2
256 GB | MU172
512 GB | MU1M2
Space Gray | 64 GB | MU0M2
256 GB | MU102
512 GB | MU1F2
J318xAP | iPad8,4 | Silver | 1 TB | MU222
Space Gray | 1 TB | MU1V2
A1979[1] | J318AP | iPad8,3 | Silver | 64 GB | MU0X2
256 GB | MU1C2
512 GB | MU1T2
Space Gray | 64 GB | MU0Q2
256 GB | MU152
512 GB | MU1J2
J318xAP | iPad8,4 | Silver | 1 TB | MU272
Space Gray | 1 TB | MU1Y2
A2013 | BCGA2013 | J318AP | iPad8,3 | Silver | 64 GB | MU0Y2
256 GB | MU1D2
512 GB | MU1U2
Space Gray | 64 GB | MU0T2
256 GB | MU162
512 GB | MU1K2
J318xAP | iPad8,4 | Silver | 1 TB | MU282
Space Gray | 1 TB | MU202
iPad Pro (12.9-inch) (3rd generation) | A1876 | Bootrom 4172.0.0.100.14 | BCGA1876 | J320AP | iPad8,5 | Silver | 64 GB | MTEM2
256 GB | MTFN2
512 GB | MTFQ2
Space Gray | 64 GB | MTEL2
256 GB | MTFL2
512 GB | MTFP2
J320xAP | iPad8,6 | Silver | 1 TB | MTFT2
Space Gray | 1 TB | MTFR2
A1895 | BCGA1985 | J321AP | iPad8,7 | Silver | 64 GB | MTHP2
256 GB | MTJ62
512 GB | MTJJ2
Space Gray | 64 GB | MTHJ2
256 GB | MTHV2
512 GB | MTJD2
J321xAP | iPad8,8 | Silver | 1 TB | MTJV2
Space Gray | 1 TB | MTJP2
A1983[1] | J321AP | iPad8,7 | Silver | 64 GB | MTHT2
256 GB | MTJ92
512 GB | MTJM2
Space Gray | 64 GB | MTHM2
256 GB | MTHY2
512 GB | MTJG2
J321xAP | iPad8,8 | Silver | 1 TB | MTJY2
Space Gray | 1 TB | MTJT2
A2014 | BCGA2014 | J321AP | iPad8,7 | Silver | 64 GB | MTHU2
256 GB | MTJA2
512 GB | MTJN2
Space Gray | 64 GB | MTHN2
256 GB | MTJ02
512 GB | MTJH2
J321xAP | iPad8,8 | Silver | 1 TB | MTL02
Space Gray | 1 TB | MTJU2
iPad Pro (11-inch) (2nd generation) | A2228 | Bootrom 4172.0.0.100.14 | BCGA2228 | J417AP | iPad8,9 | Silver | 128 GB | MY252
256 GB | MXDD2
512 GB | MXDF2
1 TB | MXDH2
Space Gray | 128 GB | MY232
256 GB | MXDC2
512 GB | MXDE2
1 TB | MXDG2
A2068 A2230 A2231 | BCGA2068 BCGA2230 | J418AP | iPad8,10 | Silver | 128 GB | MY2W2, MY342
256 GB | MXE52, MXEX2
512 GB | MXE72, MXF02
1 TB | MXE92, MXF22
Space Gray | 128 GB | MY2V2, MY332
256 GB | MXE42, MXEW2
512 GB | MXE62, MXEY2
1 TB | MXE82, MXF12
iPad Pro (12.9-inch) (4th generation) | A2229 | Bootrom 4172.0.0.100.14 | BCGA2229 | J420AP | iPad8,11 | Silver | 128 GB | MY2J2
256 GB | MXAU2
512 GB | MXAW2
1 TB | MXAY2
Space Gray | 128 GB | MY2H2
256 GB | MXAT2
512 GB | MXAV2
1 TB | MXAX2
A2069 A2232 A2233 | BCGA2069 BCGA2232 | J421AP | iPad8,12 | Silver | 128 GB | MY3D2, MY3K2
256 GB | MXF62, MXFY2
512 GB | MXF82, MXG12
1 TB | MXFA2, MXG32
Space Gray | 128 GB | MY3C2, MY3J2
256 GB | MXF52, MXFX2
512 GB | MXF72, MXG02
1 TB | MXF92, MXG22
iPad Pro (11-inch) (3rd generation) | ? | ? | ? | J517AP | iPad13,4 | Silver | 128 GB |
256 GB |
512 GB |
1 TB |
2 TB |
Space Gray | 128 GB |
256 GB |
512 GB |
1 TB |
2 TB |
? | ? | J517xAP | iPad13,5 | Silver | 128 GB |
256 GB |
512 GB |
1 TB |
2 TB |
Space Gray | 128 GB |
256 GB |
512 GB |
1 TB |
2 TB |
? | ? | J518AP | iPad13,6 | Silver | 128 GB |
256 GB |
512 GB |
1 TB |
2 TB |
Space Gray | 128 GB |
256 GB |
512 GB |
1 TB |
2 TB |
? | ? | J518xAP | iPad13,7 | Silver | 128 GB |
256 GB |
512 GB |
1 TB |
2 TB |
Space Gray | 128 GB |
256 GB |
512 GB |
1 TB |
2 TB |
iPad Pro (12.9-inch) (5th generation) | ? | ? | ? | J522AP | iPad13,8 | Silver | 128 GB |
256 GB |
512 GB |
1 TB |
2 TB |
Space Gray | 128 GB |
256 GB |
512 GB |
1 TB |
2 TB |
? | ? | J522xAP | iPad13,9 | Silver | 128 GB |
256 GB |
512 GB |
1 TB |
2 TB |
Space Gray | 128 GB |
256 GB |
512 GB |
1 TB |
2 TB |
? | ? | J523AP | iPad13,10 | Silver | 128 GB |
256 GB |
512 GB |
1 TB |
2 TB |
Space Gray | 128 GB |
256 GB |
512 GB |
1 TB |
2 TB |
? | ? | J523xAP | iPad13,11 | Silver | 128 GB |
256 GB |
512 GB |
1 TB |
2 TB |
Space Gray | 128 GB |
256 GB |
512 GB |
1 TB |
2 TB |

## iPad mini

Generation | "A" Number | Bootrom | FCC ID | Internal Name | Identifier | Finish | Storage | Model
--- | --- | --- | --- | --- | --- | --- | --- | ---
iPad mini | A1432 | ROM | BCGA1432 | P105AP | iPad2,5 | Black & Slate | 16 GB | MD528, MF432
32 GB | MD529
64 GB | MD530
White & Silver | 16 GB | MD531
32 GB | MD532
64 GB | MD533
A1454 | BCGA1454 | P106AP | iPad2,6 | Black & Slate | 16 GB | MD534, ME030, MF442, MF743
32 GB | MD535, ME031
64 GB | MD536, ME032
White & Silver | 16 GB | MD537, ME033, MF746
32 GB | MD538, ME034
64 GB | MD539, ME035
A1455 | BCGA1455 | P107AP | iPad2,7 | Black & Slate | 16 GB | MD540, ME215, MF450, MF453
32 GB | MD541, ME216
64 GB | MD542, ME217
White & Silver | 16 GB | MD543, ME218
32 GB | MD544, ME219
64 GB | MD545, ME220
iPad mini 2 | A1489 | Bootrom 1704.10 | BCGA1489 | J85AP | iPad4,4 | Silver | 16 GB | ME279
32 GB | ME280
64 GB | ME281
128 GB | ME860
Space Gray | 16 GB | ME276
32 GB | ME277
64 GB | ME278
128 GB | ME856
A1490 | BCGA1490 | J86AP | iPad4,5 | Silver | 16 GB | ME814, ME818, MF074, MF075, MF076, MF544
32 GB | ME824, MF083, MF084, MF085, MF569
64 GB | ME832, MF089, MF090, MF091, MF580
128 GB | ME840, MF120, MF121, MF123, MF594
Space Gray | 16 GB | ME800, MF066, MF069, MF070, MF078, MF519
32 GB | ME820, MF080, MF081, MF082, MF552
64 GB | ME828, MF086, MF087, MF088, MF575
128 GB | ME836, MF116, MF117, MF118, MF585
A1491 | BCGA1491 | J87AP | iPad4,6 | Silver | 16 GB | MF248
32 GB | MF252
64 GB | MF246
128 GB | MF244
Space Gray | 16 GB | MF247
32 GB | MF251
64 GB | MF245
128 GB | MF243
iPad mini 3 | A1599 | Bootrom 1704.10 | BCGA1599 | J85mAP | iPad4,7 | Gold | 16 GB | MGYE2
64 GB | MGY92
128 GB | MGYK2
Silver | 16 GB | MGNV2
64 GB | MGGT2
128 GB | MGP42
Space Gray | 16 GB | MGNR2
64 GB | MGGQ2
128 GB | MGP32
A1600 | BCGA1600 | J86mAP | iPad4,8 | Gold | 16 GB | MH3G2, MH0F2
64 GB | MH392
128 GB | MH3N2
Silver | 16 GB | MH3F2
64 GB | MH382
128 GB | MH3M2
Space Gray | 16 GB | MH3E2
64 GB | MH372
128 GB | MH3L2
A1601 | BCGA1601 | J87mAP | iPad4,9 | Gold | 16 GB | MGYR2, MGYY2
64 GB | MGYN2, MGYW2
128 GB | MGYU2, MH012
Silver | 16 GB | MGHW2, MGPW2
64 GB | MGJ12, MGQ12
128 GB | MGJ32, MGQ32
Space Gray | 16 GB | MGHV2, MGPV2
64 GB | MGJ02, MGQ02
128 GB | MGJ22, MGQ22
iPad mini 4 | A1538 | Bootrom 1992.0.0.1.19 | BCGA1538 | J96AP | iPad5,1 | Gold | 16 GB | MK6L2
32 GB | MNY32
64 GB | MK9J2
128 GB | MK9Q2
Silver | 16 GB | MK6K2
32 GB | MNY22
64 GB | MK9H2
128 GB | MK9P2
Space Gray | 16 GB | MK6J2
32 GB | MNY12
64 GB | MK9G2
128 GB | MK9N2
A1550 | BCGA1550 | J97AP | iPad5,2 | Gold | 16 GB | MK882, MK712
32 GB | MNWR2, MNWG2
64 GB | MK8C2, MK752
128 GB | MK8F2, MK782
Silver | 16 GB | MK872, MK702, MK7X2
32 GB | MNWQ2, MNWF2
64 GB | MK8A2, MK732
128 GB | MK8E2, MK772
Space Gray | 16 GB | MK862, MK7L2
32 GB | MNWP2
64 GB | MK892, MK722
128 GB | MK8D2, MK762
iPad mini (5th generation) | A2133 | Bootrom 3865.0.0.4.7 | BCGA2133 | J210AP | iPad11,1 | Gold | 64 GB | MUQY2
256 GB | MUU62
Silver | 64 GB | MUQX2
256 GB | MUU52
Space Gray | 64 GB | MUQW2
256 GB | MUU32
A2124 A2125 A2126 | BCGA2124 BCGA2126 | J211AP | iPad11,2 | Gold | 64 GB | MUXH2, MUX72
256 GB | MUXP2, MUXE2
Silver | 64 GB | MUXG2, MUX62
256 GB | MUXN2, MUXD2
Space Gray | 64 GB | MUXF2, MUX52
256 GB | MUXM2, MUXC2
iPad mini (6th generation) | A2567 | ? | BCGA2567 | J310AP | iPad14,1 | Space Gray | 64 GB | MK7M3
256 GB | MK7T3
Pink | 64 GB | MLWL3
256 GB | MLWR3
Purple | 64 GB | MK7R3
256 GB | MK7X3
Starlight | 64 GB | MK7P3
256 GB | MK7V3
A2568 A2569 | BCGA2568 BCGA2569 | J311AP | iPad14,2 | Space Gray | 64 GB | MK893
256 GB | MK8F3
Pink | 64 GB | MLX43
256 GB | MLX93
Purple | 64 GB | MK8E3
256 GB | MK8K3
Starlight | 64 GB | MK8C3
256 GB | MK8H3

## iPhone

Generation | "A" Number | Bootrom | FCC ID | Internal Name | Identifier | Finish | Storage | Model
--- | --- | --- | --- | --- | --- | --- | --- | ---
iPhone | A1203 | Bootrom Rev.2 | BCGA1203 | M68AP | iPhone1,1 | Black | 4 GB | MA501
8 GB | MA712
16 GB | MB384
iPhone 3G | A1241 A1324[1] | Bootrom Rev.2 | BCGA1241 | N82AP | iPhone1,2 | Black | 8 GB | MB046, MB489, MB639, MB702, MC176, MB490, MB757
16 GB | MB048, MB496, MB497, MB704, MB631
White | MB499, MB500, MB501, MB632, MB705
iPhone 3GS | A1303 A1325[1] | Bootrom 359.3 Bootrom 359.3.2 | BCGA1303A BCGA1303B | N88AP | iPhone2,1 | Black | 8 GB | MC555, MC640, MC637
16 GB | MB715, MB719, MB735, MC131, MC135, MC139, MC143
32 GB | MB717, MB737, MC133, MC137, MC141, MC158
White | 16 GB | MB716, MB736, MC132, MC136, MC140, MC144
32 GB | MB718, MB738, MC134, MC138, MC160
iPhone 4 | A1332 | Bootrom 574.4 | BCG-E2380A BCG-E2380B | N90AP | iPhone3,1 | Black | 8 GB | MD126, MD127, MD128
16 GB | MC318, MC603, MC608
32 GB | MC319, MC605, MC610
White | 8 GB | MD196, MD197, MD198
16 GB | MC604, MC536, MC607, MC609
32 GB | MC606, MC537, MC611
BCG-E2380A BCG-E2380B | N90bAP | iPhone3,2 | Black | 8 GB | MD128, ME798
White | ME799
A1349 | BCG-E2422A BCG-E2422B | N92AP | iPhone3,3 | Black | 8 GB | MD146, MD439, MD873, ME639
16 GB | MC676
32 GB | MC678
White | 8 GB | MD200, MD440, MD874
16 GB | MC677
32 GB | MC679
iPhone 4S | A1387 A1431[1] | Bootrom 838.3 | BCG-E2430A | N94AP | iPhone4,1 | Black | 8 GB | ME259, MF257, MF261, MF263, MF265, MF269, MF259, MF267
16 GB | MC918, MC922, MD234, MD235, MD276, MD377, MD865, ME804, MD236, MD251, MD254
32 GB | MC919, MC923, MD241, MD242, MD278, MD379, MD261, MD243
64 GB | MD257, MD258, MD269, MD280, MD381, MD259, MD270
White | 8 GB | MF258, MF260, MF262, MF264, MF266, MF270, MF268
16 GB | MC920, MC924, MD237, MD239, MD277, MD378, MD866, ME805, MD240, MD920
32 GB | MC921, MD244, MD279, MD380, MD246, MD245, MC925
64 GB | MD260, MD271, MD272, MD281, MD382, MD262
iPhone 5 | A1428 | Bootrom 1145.3 | BCG-E2599A | N41AP | iPhone5,1 | Black & Slate | 16 GB | MD293, MD634, MD638, ME486
32 GB | MD295, MD636, ME488, MD640
64 GB | MD642, MD644, ME490, MD646
White & Silver | 16 GB | MD294, MD635, ME487, MD639
32 GB | MD296, MD637, ME489, MD641
64 GB | MD643, MD645, ME491, MD647
A1429 A1442[1] | N42AP | iPhone5,2 | Black & Slate | 16 GB | MD297, MD654, MD656, ME039, MD097, MD669, MD671
32 GB | MD299, MD658, MD660, ME041
64 GB | MD662, MD664, MD667, ME043
White & Silver | 16 GB | MD298, MD655, MD657, ME040, MD105, MD672
32 GB | MD300, MD659, MD661, ME042, MD144
64 GB | MD663, MD665, MD668, ME044
iPhone 5c | A1456 A1532 | Bootrom 1145.3 | BCG-E2644A | N48AP | iPhone5,3 | Blue | 16 GB | ME507, ME531, ME543
32 GB | MF136, MF151
Green | 16 GB | ME508, ME496, ME544, ME568
32 GB | MF137, MF152
Pink | 16 GB | ME509, ME533, ME545
32 GB | MF138, MF133, MF153
White | 16 GB | ME505, ME493, ME541, ME565
32 GB | MF134, MF149
Yellow | 8 GB | MGF12
16 GB | ME506
32 GB | MF135
A1507 A1516[1] A1526 A1529 | BCG-E2694A BCG-E2694B | N49AP | iPhone5,4 | Blue | 8 GB | MG0T2, MG1U2, MG902
16 GB | ME555, ME501, ME561, MF323, MF333
32 GB | MF156
Green | 8 GB | MG0V2(?), MG1W2(?), MG912
16 GB | ME556, ME502, MF324
32 GB | MF157, MF095, MF329
Pink | 8 GB | MG0V2(?), MG1W2(?), MG922
16 GB | ME557, ME503
32 GB | MF158, MF330
White | 8 GB | MG0Q2, MG1Q2, MG8X2
16 GB | ME553, ME499, MF321
32 GB | MF154, MF326
Yellow | 8 GB | MG0R2, MG1R2, MG8Y2
16 GB | ME554, MF322
32 GB | MF155, MF327
iPhone 5s | A1453 A1533 | Bootrom 1704.10 | BCG-E2642A | N51AP | iPhone6,1 | Gold | 16 GB | ME298, ME307, ME325, ME343, ME334
32 GB | ME301, ME310, ME328, ME346, ME337
64 GB | ME304, ME313, ME331, ME349, ME340
Silver | 16 GB | ME297, ME306, ME324, ME333, ME342
32 GB | ME300, ME309, ME327, ME345, ME336
64 GB | ME303, ME312, ME348, ME339, ME330, MF359
Space Gray | 16 GB | ME296, ME305, ME323, ME341, ME332, MF797
32 GB | ME299, ME308, ME326, ME344, ME335, MF384
64 GB | ME302, ME311, ME329, ME347, ME338
A1457 A1518[1] A1528[1] A1530 | BCG-E2643A BCG-E2643B | N53AP | iPhone6,2 | Gold | 16 GB | ME434, MF354, MF398, MF363
32 GB | ME437, MF357
64 GB | ME440, MF360
Silver | 16 GB | ME433, MF353, MF362
32 GB | ME436, MF356
64 GB | ME439
Space Gray | 16 GB | ME432, MF352
32 GB | ME435, MF355
64 GB | ME438, MF358
iPhone 6 | A1549 A1586 A1589[1] | Bootrom 1992.0.0.1.19 | BCG-E2816A | N61AP | iPhone7,2 | Gold | 16 GB | MG3D2, MG492, MG4Q2, MG562, MG5Y2, MG6C2
32 GB[2] | MQ3E2
64 GB | MG3L2, MG4J2, MG502, MG652, MG6J2, MG842
128 GB | MG3G2, MG4E2, MG4V2, MG622
Silver | 16 GB | MG3C2, MG4P2, MG482, MG5X2, MG552, MG6A2, MG7W2
64 GB | MG3K2, MG4H2, MG4X2, MG5C2, MG6H2, MG642, MG822
128 GB | MG3F2, MG4C2, MG612
Space Gray | 16 GB | MG3A2, MG4N2, MG472, MG5H2, MG5W2, MG542, MG692
32 GB[2] | MQ3D2, MQ462
64 GB | MG3H2, MG4F2, MG4W2, MG5A2, MG6G2, MG632
128 GB | MG3E2, MG4A2, MG4R2, MG602
iPhone 6 Plus | A1522 A1524 A1593[1] | Bootrom 1992.0.0.1.19 | BCG-E2817A | N56AP | iPhone7,1 | Gold | 16 GB | MGAA2, MGAN2, MGC12, MGCM2, MGCX2
64 GB | MGAK2, MGAW2, MGC72, MGCU2
128 GB | MGAF2, MGAR2, MGC42, MGCQ2
Silver | 16 GB | MGA92, MGC92, MGAM2, MGC02, MGCL2
64 GB | MGAJ2, MGAV2, MGC62, MGCT2
128 GB | MGAE2, MGAQ2, MGC32, MGCP2
Space Gray | 16 GB | MGA82, MGAL2, MGAX2, MGCK2
64 GB | MGAH2, MGAU2, MGC52, MGCR2
128 GB | MGAC2, MGAP2, MGC22, MGCN2
iPhone 6s | A1633 A1688 A1691[1] A1700[1] | Bootrom 2234.0.0.3.3 (S8000) Bootrom 2234.0.0.2.22 (S8003) | BCG-E2946A | N71AP N71mAP | iPhone8,1 | Gold | 16 GB | MKQL2, MKQ72, MKR12, MKRE2, MKRW2, MKT92, ML7E2
32 GB | MN0P2, MN172, MN1K2, MN1U2, MN1Y2, MN112
64 GB | MKQC2, MKQQ2, MKR52, MKRJ2, MKT12, MKTE2, ML7J2
128 GB | MKQG2, MKQV2, MKR92, MKRP2, MKT52, MKTJ2, ML7N2
Rose Gold | 16 GB | MKQM2, MKQ82, MKRF2, MKRX2, MKR22, MKTA2, ML7F2
32 GB | MN0V2, MN192, MN1L2, MN1V2, MN202, MN122
64 GB | MKQD2, MKQR2, MKR62, MKRK2, MKT22, MKTF2, ML7K2
128 GB | MKQH2, MKQW2, MKRA2, MKRQ2, MKT62, MKTK2, ML7P2
Silver | 16 GB | MKQ62, MKQK2, MKQY2, MKRD2, MKRT2, MKT82, ML7D2, NKQJ2
32 GB | MN0N2, MN162, MN1G2, MN1Q2, MN1X2, MN0X2
64 GB | MKQA2, MKQP2, MKR42, MKRH2, MKT02, MKTD2, ML7H2
128 GB | MKQF2, MKQU2, MKR82, MKRM2, MKT42, MKTH2, ML7M2
Space Gray | 16 GB | MKQ52, MKQJ2, MKQX2, MKRC2, MKRR2, MKT72, ML7C2
32 GB | MN0M2, MN132, MN1E2, MN1M2, MN1W2, MN0W2
64 GB | MKQN2, MKQ92, MKR32, MKRG2, MKRY2, MKTC2, ML7G2
128 GB | MKQE2, MKQT2, MKR72, MKRL2, MKT32, MKTG2, ML7L2
iPhone 6s Plus | A1634 A1687 A1690[1] A1699[1] | Bootrom 2234.0.0.3.3 (S8000) Bootrom 2234.0.0.2.22 (S8003) | BCG-E2944A | N66AP N66mAP | iPhone8,2 | Gold | 16 GB | MKTN2, MKU32, MKUN2, MKV62, MKVQ2, MKW72, ML6D2
32 GB | MN2X2
64 GB | MKTT2, MKU82, MKUV2, MKVD2, MKVX2, MKWD2, ML6H2
128 GB | MKTX2, MKUF2, MKV12, MKVH2, MKW22, MKWH2, ML6M2
Rose Gold | 16 GB | MKU52, ML6E2, MKTP2, MKUP2, MKV72, MKVU2, MKW82
32 GB | MN2Y2
64 GB | MKU92, ML6J2, MKTU2, MKUW2, MKVE2, MKVY2, MKWE2
128 GB | MKUG2, MKV22, ML6N2, MKVJ2, MKTY2
Silver | 16 GB | MKTM2, MKU22, MKUJ2, MKV52, MKVP2, MKW62, ML6C2
64 GB | MKTR2, MKU72, MKUU2, MKV92, MKVW2, MKWC2, ML6G2
128 GB | MKTW2, MKUE2, MKUY2, MKVG2, MKW12, MKWG2, ML6L2
Space Gray | 16 GB | MKU12, ML6A2, MKV32, MKTL2, MKUH2, MKVN2, MKW52
32 GB | MN2V2
64 GB | MKU62, ML6F2, MKTQ2, MKUQ2, MKV82, MKVV2, MKW92, ML642
128 GB | MKUD2, ML6K2, MKTV2, MKUX2, MKVF2, MKW02, MKWF2
iPhone SE (1st generation) | A1662 A1723 A1724[1] | Bootrom 2234.0.0.3.3 (S8000) Bootrom 2234.0.0.2.22 (S8003) | BCG-E2945A BCG-E3042A | N69AP N69uAP | iPhone8,4 | Gold | 16 GB | MLXH2, MLXW2, MLY12, MLY52, MLY92, MLXM2
32 GB | MP8D2, MP8R2, MP8H2, MP8M2, MP7V2, MP842
64 GB | MLXK2, MLXY2, MLY32, MLY72, MLYC2, MLXP2
128 GB | MP952, MP9J2, MP992, MP9E2, MP802, MP882
Rose Gold | 16 GB | MLXJ2, MLXX2, MLY22, MLY62, MLYA2, MLXN2
32 GB | MP8E2, MP8T2, MP8J2, MP8N2, MP7W2, MP852
64 GB | MLXL2, MLY02, MLY42, MLY82, MLYD2, MLXQ2
128 GB | MP962, MP9K2, MP9A2, MP9F2, MP812, MP892
Silver | 16 GB | MLLM2, MLLV2, MLLX2, MLM02, MLM32, MLLP2
32 GB | MP8C2, MP8Q2, MP8G2, MP8L2, MP7U2, MP832
64 GB | MLM52, MLMC2, MLME2, MLMG2, MLMJ2, MLM72
128 GB | MP942, MP9H2, MP982, MP9D2, MP7Y2, MP872
Space Gray | 16 GB | MLLL2, MLLU2, MLLW2, MLLY2, MLM22, MLLN2
32 GB | MP8A2, MP8P2, MP8F2, MP8K2, MP7T2, MP822
64 GB | MLM42, MLM62, MLMA2, MLMD2, MLMF2, MLMH2
128 GB | MP932, MP9G2, MP972, MP9C2, MP7X2, MP862
iPhone 7 | A1660 A1779[3] A1780 | Bootrom 2696.0.0.1.33 | BCG-E3085A BCG-E3086A | D10AP | iPhone9,1 | Black | 32 GB | MN8G2, MNAC2, MNAY2, MNCE2, MNGQ2
128 GB | MN8L2, MNAJ2, MNC32, MNCK2, MNGX2
256 GB | MN8R2, MNAQ2, MNC82, MNCQ2
Gold | 32 GB | MN8J2, MNAE2, MNC12, MNCG2
128 GB | MN8N2, MNAL2, MNC52, MNCM2, MNH02
256 GB | MN8U2, MNAV2, MNCA2, MNCT2, MN992
Jet Black | 128 GB | MN8Q2, MNAP2, MNC72, MNCP2
256 GB | MN8W2, MNAX2, MNCD2, MNCV2
PRODUCT(RED) | 128 GB | MPRV2, MPRT2, MPRH2, MPRL2
256 GB | MPRW2, MPRU2, MPRJ2, MPRM2
Rose Gold | 32 GB | MN8K2, MNAF2, MNC22, MNCJ2
128 GB | MN8P2, MNAM2, MNC62, MNH12, MNCN2
256 GB | MN8V2, MNAW2, MNCC2, MNCU2, MN9A2
Silver | 32 GB | MN8H2, MNAD2, MNC02, MNCF2, MN8Y2
128 GB | MN8M2, MNAK2, MNC42, MNCL2,a MN932
256 GB | MN8T2, MNAU2, MNC92, MNCR2, MN982
A1778 | BCG-E3091A | D101AP | iPhone9,3 | Black | 32 GB | MN9D2, MN9U2, MN8X2
128 GB | MN9H2, MN9Y2, MN922
256 GB | MN9N2, MNA62, MN972
Gold | 32 GB | MN9F2, MN9W2, MN902
128 GB | MN9K2, MNA32, MN942
256 GB | MN9Q2, MNA82
Jet Black | 32 GB | MQTR2, MQTX2
128 GB | MN9M2, MNA52, MN962
256 GB | MN9T2, MNAA2, MN9C2
PRODUCT(RED) | 128 GB | MPRN2, MPRQ2
256 GB | MPRP2, MPRR2
Rose Gold | 32 GB | MN9G2, MN9X2, MN912
128 GB | MN9L2, MNA42, MN952
256 GB | MN9R2, MNA92
Silver | 32 GB | MN9E2, MN9V2
128 GB | MN9J2, MNA02
256 GB | MN9P2, MNA72
iPhone 7 Plus | A1661 A1785[3] A1786 | Bootrom 2696.0.0.1.33 | BCG-E3087A BCG-E3088A | D11AP | iPhone9,2 | Black | 32 GB | MNQH2, MNR12, MNR52, MNR92, MNRJ2
128 GB | MN482, MN5T2, MN642, MN6F2, MNFP2
256 GB | MN4E2, MN5Y2, MN692, MN6L2, MNFV2
Gold | 32 GB | MNQK2, MNR32, MNR72, MNRC2, MNRL2
128 GB | MN4A2, MN5V2, MN662, MN6H2, MNFR2
256 GB | MN4J2, MN612, MN6C2, MN6N2
Jet Black | 32GB | MQU22
128 GB | MN4D2, MN5X2, MN682, MN6K2
256 GB | MN4L2, MN632, MN6E2, MN6Q2
PRODUCT(RED) | 128 GB | MPR12, MPR02, MPQV2, MPQW2
256 GB | MPRA2, MPR92, MPR52, MPR62
Rose Gold | 32 GB | MNQL2, MNR42, MNR82, MNRD2, MNRM2
128 GB | MN4C2, MN5W2, MN672, MN6J2, MNFT2
256 GB | MN4K2, MN622, MN6D2, MN6P2, MNFY2
Silver | 32 GB | MNQJ2, MNR22, MNR62, MNRA2, MNRK2
128 GB | MN492, MN5U2, MN652, MN6G2, MNFQ2
256 GB | MN4F2, MN602, MN6A2, MN6M2
A1784 | BCG-E3092A | D111AP | iPhone9,4 | Black | 32 GB | MNQR2, MNQW2, MNQM2
128 GB | MN522, MN5G2, MN4M2
256 GB | MN592, MN5M2, MN4W2
Gold | 32 GB | MNQU2, MNQY2, MNQP2
128 GB | MN552, MN5J2, MN4Q2
256 GB | MN5D2, MN5P2, MN4Y2
Jet Black | 128 GB | MN572, MN5L2, MN4V2
256 GB | MN5F2, MN5R2, MN512
PRODUCT(RED) | 128 GB | MPQW2, MPQY2
256 GB | MPR72, MPR82
Rose Gold | 32 GB | MNQV2, MNR02, MNQQ2
128 GB | MN562, MN5K2, MN4U2
256 GB | MN5E2, MN5Q2
Silver | 32 GB | MNQT2, MNQX2, MNQN2
128 GB | MN532, MN5H2, MN4P2
256 GB | MN5C2, MN5N2, MN4X2, MN502
iPhone 8 | A1863 A1906[4] A1907 | Bootrom 3332.0.0.1.23 | BCG-E3159A BCG-E3171A | D20AP | iPhone10,1 | Gold | 64 GB | MQ6M2, MQ742, MQ772, MQ7A2
256 GB | MQ7H2, MQ802, MQ832, MQ862
Silver | 64 GB | MQ6L2, MQ732, MQ762, MQ792
256 GB | MQ7G2, MQ7Y2, MQ822, MQ852
Space Gray | 64 GB | MQ6K2, MQ722, MQ752, MQ782
128 GB | MX132
256 GB | MQ7F2, MQ7X2, MQ812, MQ842
D20AAP | PRODUCT(RED) | 64 GB | MRRK2, MRRR2, MRRT2
256 GB | MRRL2, MRRW2, MRRX2
A1905 | BCG-E3172A | D201AP | iPhone10,4 | Gold | 64 GB | MQ6J2, MQ6X2, MQ712
256 GB | MQ7E2, MQ7T2, MQ7W2
Silver | 64 GB | MQ6H2, MQ6W2, MQ702
256 GB | MQ7D2, MQ7R2, MQ7V2
Space Gray | 64 GB | MQ6G2, MQ6V2, MQ6Y2
256 GB | MQ7C2, MQ7Q2, MQ7U2
D201AAP | PRODUCT(RED) | 64 GB | MRRM2, MRRP2, MRRQ2
256 GB | MRRN2, MRRU2, MRRV2
iPhone 8 Plus | A1864 A1898[4] A1899 | Bootrom 3332.0.0.1.23 | BCG-E3160A BCG-E3173A | D21AP | iPhone10,2 | Gold | 64 GB | MQ8F2, MQ9F2, MQ982, MQ9M2
256 GB | MQ8J2, MQ9C2, MQ9J2, MQ9Q2
Silver | 64 GB | MQ8E2, MQ9E2, MQ972, MQ9L2
256 GB | MQ8H2, MQ9A2, MQ9H2, MQ9P2
Space Gray | 64 GB | MQ8D2, MQ9D2, MQ962, MQ9K2
256 GB | MQ8G2, MQ9G2, MQ992, MQ9N2
D21AAP | PRODUCT(RED) | 64 GB | MRTG2, MRTJ2, MRT72
256 GB | MRTH2, MRTK2, MRT82
A1897 | BCG-E3174A | D211AP | iPhone10,5 | Gold | 64 GB | MQ8N2, MQ8V2, MQ922
256 GB | MQ8R2, MQ8Y2, MQ952
Silver | 64 GB | MQ8M2, MQ8U2, MQ912
256 GB | MQ8Q2, MQ8X2, MQ942
Space Gray | 64 GB | MQ8L2, MQ8T2, MQ902
256 GB | MQ8P2, MQ8W2, MQ932
D211AAP | PRODUCT(RED) | 64 GB | MRTC2, MRTE2, MRT92
256 GB | MRTA2, MRTD2, MRTF2
iPhone X | A1865 A1902[4] | Bootrom 3332.0.0.1.23 | BCG-E3161A | D22AP | iPhone10,3 | Silver | 64 GB | MQCT2, MQCL2, MQAY2, MQA62
256 GB | MQCW2, MQCP2, MQC22, MQA92
Space Gray | 64 GB | MQCR2, MQCK2, MQAX2, MQA52
256 GB | MQCV2, MQCN2, MQC12, MQA82
A1901 | BCG-E3175A | D221AP | iPhone10,6 | Silver | 64 GB | MQAK2, MQAR2, MQAD2
256 GB | MQAN2, MQAV2, MQAG2
Space Gray | 64 GB | MQAJ2, MQAQ2, MQAC2
256 GB | MQAM2, MQAU2, MQAF2
iPhone XR | A1984 | Bootrom 3865.0.0.4.7 | BCG-E3220A | N841AP | iPhone11,8 | Black | 64 GB | MT3K2, MT2E2, MT302, MT472
128 GB | MT3T2, MT2L2, MT362, MT4G2
256 GB | MT402, MT2T2, MT3D2, MT4R2
Blue | 64 GB | MT3R2, MT2K2, MT352, MT4F2
128 GB | MT3Y2, MT2R2, MT3C2, MT4Q2
256 GB | MT462, MT2Y2, MT3J2, MT4Y2
Coral | 64 GB | MT3Q2, MT2J2, MT342, MT4D2
128 GB | MT3X2, MT2Q2, MT3A2, MT4N2
256 GB | MT452, MT2X2, MT3H2, MT4X2
PRODUCT(RED) | 64 GB | MT3M2, MT2G2, MT322, MT492
128 GB | MT3V2, MT2N2, MT382, MT4J2
256 GB | MT422, MT2V2, MT3F2, MT4V2
White | 64 GB | MT3L2, MT2F2, MT312, MT482
128 GB | MT3U2, MT2M2, MT372, MT4H2
256 GB | MT412, MT2U2, MT3E2, MT4U2
Yellow | 64 GB | MT3N2, MT2H2, MT332, MT4A2
128 GB | MT3W2, MT2P2, MT392, MT4L2
256 GB | MT442, MT2W2, MT3G2, MT4W2
A2105 | BCG-E3237A | Black | 64 GB | MRY42
128 GB | MRY92
256 GB | MRYJ2
Blue | 64 GB | MRYA2
128 GB | MRYH2
256 GB | MRYQ2
Coral | 64 GB | MRY82
128 GB | MRYG2
256 GB | MRYP2
PRODUCT(RED) | 64 GB | MRY62
128 GB | MRYE2
256 GB | MRYM2
White | 64 GB | MRY52
128 GB | MRYD2
256 GB | MRYL2
Yellow | 64 GB | MRY72
128 GB | MRYF2
256 GB | MRYN2
A2106[4] | BCG-E3238A | Black | 64 GB | MT002
128 GB | MT0G2
256 GB | MT0V2
Blue | 64 GB | MT0E2
128 GB | MT0U2
256 GB | MT112
Coral | 64 GB | MT0A2
128 GB | MT0T2
256 GB | MT102
PRODUCT(RED) | 64 GB | MT062
128 GB | MT0N2
256 GB | MT0X2
White | 64 GB | MT032
128 GB | MT0J2
256 GB | MT0W2
Yellow | 64 GB | MT082
128 GB | MT0Q2
256 GB | MT0Y2
A2108[5] | BCG-E3220A | Black | 64 GB | MT122
128 GB | MT192
256 GB | MT1H2
Blue | 64 GB | MT182
128 GB | MT1G2
256 GB | MT1Q2
Coral | 64 GB | MT172
128 GB | MT1F2
256 GB | MT1P2
PRODUCT(RED) | 64 GB | MT142
128 GB | MT1D2
256 GB | MT1L2
White | 64 GB | MT132
128 GB | MT1A2
256 GB | MT1J2
Yellow | 64 GB | MT162
128 GB | MT1E2
256 GB | MT1M2
iPhone XS | A1920 | Bootrom 3865.0.0.4.7 | BCG-E3218A | D321AP | iPhone11,2 | Gold | 64 GB | MT8W2, MTA22, MT8L2, MTAJ2, MT962
256 GB | MT902, MTA92, MT8P2, MTAQ2, MT992
512 GB | MT932, MTAF2, MT8T2, MTAV2, MT9D2
Silver | 64 GB | MT8V2, MTA12, MT8K2, MTAH2, MT952
256 GB | MT8Y2, MTA82, MT8N2, MTAN2, MT982
512 GB | MT922, MTAD2, MT8R2, MTAU2, MT9C2
Space Gray | 64 GB | MT8U2, MTA02, MT8J2, MTAG2, MT942
256 GB | MT8X2, MTA72, MT8M2, MTAL2, MT972
512 GB | MT912, MTAA2, MT8Q2, MTAR2, MT9A2
A2097 | BCG-E3232A | Gold | 64 GB | MT9G2
256 GB | MT9K2
512 GB | MT9N2
Silver | 64 GB | MT9F2
256 GB | MT9J2
512 GB | MT9M2
Space Gray | 64 GB | MT9E2
256 GB | MT9H2
512 GB | MT9L2
A2098[4] | BCG-E3233A | Gold | 64 GB | MTAY2
256 GB | MTE22
512 GB | MTE52
Silver | 64 GB | MTAX2
256 GB | MTE12
512 GB | MTE42
Space Gray | 64 GB | MTAW2
256 GB | MTE02
512 GB | MTE32
A2100[1] | BCG-E3218A | Gold | 64 GB | MT9R2
256 GB | MT9V2
512 GB | MT9Y2
Silver | 64 GB | MT9Q2
256 GB | MT9U2
512 GB | MT9X2
Space Gray | 64 GB | MT9P2
256 GB | MT9T2
512 GB | MT9W2
iPhone XS Max | A1921 | Bootrom 3865.0.0.4.7 | BCG-E3219A | D331pAP | iPhone11,6 | Gold | 64 GB | MT5X2, MT672, MT5M2, MT6H2, MT5C2, 3D897[6]
256 GB | MT612, MT6A2, MT5Q2, MT6L2, MT5F2
512 GB | MT642, MT6E2, MT5U2, MT6P2, MT5J2
Silver | 64 GB | MT5W2, MT662, MT5L2, MT6G2, MT5A2
256 GB | MT602, MT692, MT5P2, MT6K2, MT5E2
512 GB | MT632, MT6D2, MT5T2, MT6N2, MT5H2
Space Gray | 64 GB | MT5V2, MT652, MT5K2, MT6F2, MT592
256 GB | MT5Y2, MT682, MT5N2, MT6J2, MT5D2
512 GB | MT622, MT6C2, MT5R2, MT6M2, MT5G2
A2101 | BCG-E3234A | Gold | 64 GB | MT522, 3D879[6]
256 GB | MT552
512 GB | MT582
Silver | 64 GB | MT512
256 GB | MT542
512 GB | MT572
Space Gray | 64 GB | MT502
256 GB | MT532
512 GB | MT562
A2102[4] | BCG-E3235A | Gold | 64 GB | MT6T2
256 GB | MT6W2
512 GB | MT702
Silver | 64 GB | MT6R2
256 GB | MT6V2
512 GB | MT6Y2
Space Gray | 64 GB | MT6Q2
256 GB | MT6U2
512 GB | MT6X2
A2104[5] | BCG-E3219A | Gold | 64 GB | MT732
256 GB | MT762
512 GB | MT792
Silver | 64 GB | MT722
256 GB | MT752
512 GB | MT782
Space Gray | 64 GB | MT712
256 GB | MT742
512 GB | MT772
A2103[7] | ? | D331AP | iPhone11,4 | Gold | 64 GB | MT7D2
256 GB | MT7G2
512 GB | ?
Silver | 64 GB | ?
256 GB | ?
512 GB | ?
Space Gray | 64 GB | ?
256 GB | MT7E2
512 GB | ?
iPhone 11 | A2111 | Bootrom 4479.0.0.100.4 | BCG-E3309A | N104AP | iPhone12,1 | Black | 64 GB | MWHT2, MWK02, MWJE2, MWKM2, MWL72
128 GB | MWJ02, MWK72, MWJL2, MWKU2, MWLE2
256 GB | MWJ62, MWKF2, MWJT2, MWL12, MWLL2
Green | 64 GB | MWHY2, MWK62, MWJK2, MWKT2, MWLD2
128 GB | MWJ52, MWKE2, MWJR2, MWL02, MWLK2
256 GB | MWJD2, MWKL2, MWJY2, MWL62, MWLR2
PRODUCT(RED) | 64 GB | MWHV2, MWK22, MWJG2, MWKP2, MWL92
128 GB | MWJ22, MWK92, MWJN2, MWKW2, MWLG2
256 GB | MWJ92, MWKH2, MWJV2, MWL32, MWLN2
Purple | 64 GB | MWHX2, MWK52, MWJJ2, MWKR2, MWLC2
128 GB | MWJ42, MWKD2, MWJQ2, MWKY2, MWLJ2
256 GB | MWJC2, MWKK2, MWJX2, MWL52, MWLQ2
White | 64 GB | MWHU2, MWK12, MWJF2, MWKN2, MWL82
128 GB | MWJ12, MWK82, MWJM2, MWKV2, MWLF2
256 GB | MWJ72, MWKG2, MWJU2, MWL22, MWLM2
Yellow | 64 GB | MWHW2, MWK32, MWJH2, MWKQ2, MWLA2
128 GB | MWJ32, MWKC2, MWJP2, MWKX2, MWLH2
256 GB | MWJA2, MWKJ2, MWJW2, MWL42, MWLP2
A2221 | Black | 64 GB | MWLT2
128 GB | MWM02
256 GB | MWM72
Green | 64 GB | MWLY2
128 GB | MWM62
256 GB | MWMD2
PRODUCT(RED) | 64 GB | MWLV2
128 GB | MWM32
256 GB | MWM92
Purple | 64 GB | MWLX2
128 GB | MWM52
256 GB | MWMC2
White | 64 GB | MWLU2
128 GB | MWM22
256 GB | MWM82
Yellow | 64 GB | MWLW2
128 GB | MWM42
256 GB | MWMA2
A2223[5] | Black | 64 GB | MWN02
128 GB | MWN72
256 GB | MWNF2
Green | 64 GB | MWN62
128 GB | MWNE2
256 GB | MWNL2
PRODUCT(RED) | 64 GB | MWN22
128 GB | MWN92
256 GB | MWNH2
Purple | 64 GB | MWN52
128 GB | MWND2
256 GB | MWNK2
White | 64 GB | MWN12
128 GB | MWN82
256 GB | MWNG2
Yellow | 64 GB | MWN32
128 GB | MWNC2
256 GB | MWNJ2
iPhone 11 Pro | A2160 | Bootrom 4479.0.0.100.4 | BCG-E3309A | D421AP | iPhone12,3 | Gold | 64 GB | MW9E2, MWA82, MW9T2, MWAQ2, MWCK2
256 GB | MW9J2, MWAE2, MW9X2, MWAV2, MWCP2
512 GB | MW9N2, MWAJ2, MWA42, MWC02, MWCU2
Midnight Green | 64 GB | MW9F2, MWA92, MW9U2, MWAR2, MWCL2
256 GB | MW9K2, MWAF2, MW9Y2, MWAW2, MWCQ2
512 GB | MW9P2, MWAL2, MWA52, MWC12, MWCV2
Silver | 64 GB | MW9D2, MWA72, MW9R2, MWAP2, MWCJ2
256 GB | MW9H2, MWAD2, MW9W2, MWAU2, MWCN2
512 GB | MW9M2, MWAH2, MWA32, MWAY2, MWCT2
Space Gray | 64 GB | MW9C2, MWA62, MW9Q2, MWAM2, MWCH2
256 GB | MW9G2, MWAA2, MW9V2, MWAT2, MWCM2
512 GB | MW9L2, MWAG2, MWA12, MWAX2, MWCR2
A2215 | Gold | 64 GB | MWC52
256 GB | MWC92
512 GB | MWCF2
Midnight Green | 64 GB | MWC62
256 GB | MWCC2
512 GB | MWCG2
Silver | 64 GB | MWC32
256 GB | MWC82
512 GB | MWCE2
Space Gray | 64 GB | MWC22
256 GB | MWC72
512 GB | MWCD
A2217[5] | Gold | 64 GB | MWDC2
256 GB | MWDG2
512 GB | MWDL2
Midnight Green | 64 GB | MWDD2
256 GB | MWDH2
512 GB | MWDM2
Silver | 64 GB | MWDA2
256 GB | MWDF2
512 GB | MWDK2
Space Gray | 64 GB | MWD92
256 GB | MWDE2
512 GB | MWDJ2
iPhone 11 Pro Max | A2161 | Bootrom 4479.0.0.100.4 | BCG-E3309A | D431AP | iPhone12,5 | Gold | 64 GB | MWFC2, MWG42, MWFQ2, MWGH2, MWH12
256 GB | MWFG2, MWG82, MWFV2, MWGM2, MWH62
512 GB | MWFL2, MWGD2, MWG02, MWGR2, MWHA2
Midnight Green | 64 GB | MWFD2, MWG52, MWFR2, MWGJ2, MWH22
256 GB | MWFH2, MWG92, MWFW2, MWGN2, MWH72
512 GB | MWFM2, MWGE2, MWG12, MWGT2, MWHC2
Silver | 64 GB | MWFA2, MWG32, MWFP2, MWGG2, MWH02
256 GB | MWFF2, MWG72, MWFU2, MWGL2, MWH52
512 GB | MWFK2, MWGC2, MWFY2, MWGQ2, MWH92
Space Gray | 64 GB | MWF92, MWG22, MWFN2, MWGF2, MWGY2
256 GB | MWFE2, MWG62, MWFT2, MWGK2, MWH42
512 GB | MWFJ2, MWGA2, MWFX2, MWGP2, MWH82
A2220 | Gold | 64 GB | MWHG2
256 GB | MWHL2
512 GB | MWHQ2
Midnight Green | 64 GB | MWHH2
256 GB | MWHM2
512 GB | MWHR2
Silver | 64 GB | MWHF2
256 GB | MWHK2
512 GB | MWHP2
Space Gray | 64 GB | MWHD2
256 GB | MWHJ2
512 GB | MWHN2
A2218[5] | Gold | 64 GB | MWEX2
256 GB | MWF32
512 GB | MWF72
Midnight Green | 64 GB | MWF02
256 GB | MWF42
512 GB | MWF82
Silver | 64 GB | MWEW2
256 GB | MWF22
512 GB | MWF62
Space Gray | 64 GB | MWEV2
256 GB | MWF12
512 GB | MWF52
iPhone SE (2nd generation) | A2275 A2296 A2298 | Bootrom 4479.0.0.100.4 | E3500A E3501A | D79AP | iPhone12,8 | White | 64 GB | MX9T2, MX9A2, MX9H2, MX9E2, MX9L2, MX9P2, MXAN2, MHGQ3
128 GB | MXD12, MXCJ2, MXCQ2, MXCM2, MXCU2, MXCX2, MXD72, MHGU3
256 GB | MXVU2, MXVC2, MXVJ2, MXVF2, MXVM2, MXVQ2, MXW12, MHGX3
Black | 64 GB | MX9R2, MX992, MX9G2, MX9D2, MX9K2, MX9N2, MXAM2, MHGP3
128 GB | MXD02, MXCH2, MXCP2, MXCL2, MXCT2, MXCW2, MXD62, MHGT3
256 GB | MXVT2, MXVA2, MXVH2, MXVE2, MXVL2, MXVP2, MXW02, MHGW3
PRODUCT(RED) | 64 GB | MX9U2, MX9C2, MX9J2, MX9F2, MX9M2, MX9Q2, MXAP2, MHGR3
128 GB | MXD22, MXCK2, MXCR2, MXCN2, MXCV2, MXCY2, MXD82, MHGV3
256 GB | MXVV2, MXVD2, MXVK2, MXVG2, MXVN2, MXVR2, MXW22, MHGY3
iPhone 12 mini | A2176 A2398 A2400 A2399 | Bootrom 5281.0.0.100.45 | BCG-E3539A | D52gAP | iPhone13,1 | White | 64 GB | MG803, MGDY3, MG613, MG7H3, MG713, MG6H3, MG8G3, MGA63
128 GB | MG853, MGE43, MG8M3, MG663, MG7N3, MG763, MG6N3, MGDM3
256 GB | MG8A3, MGEA3, MG6C3, MG7U3, MG7C3, MG6V3, MG8T3, MGDT3
Black | 64 GB | MG7Y3, MGDX3, MG603, MG7G3, MG703, MG6G3, MG8F3, MGA03
128 GB | MG843, MGE33, MG653, MG7M3, MG753, MG6M3, MG8L3, MGDJ3
256 GB | MG893C, MGE93, MG8R3, MG6A3, MG7T3, MG7A3, MG6U3, MGDR3
PRODUCT(RED) | 64 GB | MG813, MGE03, MG623, MG7J3, MG723, MG6J3, MG8H3, MGAE3
128 GB | MG863, MGE53, MG8N3, MG673, MG7P3, MG6P3, MG773, MGDN3
256 GB | MG8C3, MGEC3, MG6D3, MG7V3, MG7D3, MG6W3, MG8U3, MGDU3
Green | 64 GB | MG833, MGE23, MG8K3, MG643, MG7L3, MG743, MG6L3, MGAV3
128 GB | MG883, MGE73, MG693, MG7R3, MG793, MG6T3, MG8Q3, MGDQ3
256 GB | MG8E3, MGEE3, MG8W3, MG6F3, MG7X3, MG7F3, MG6Y3, MGDW3
Blue | 64 GB | MG823, MGE13, MG8J3, MG633, MG7K3, MG733, MG6K3, MGAP3
128 GB | MG873, MGE63, MG683, MG7Q3, MG783, MG6Q3, MG8P3, MGDP3
256 GB | MG8D3, MGED3, MG6E3, MG7W3, MG7E3, MG6X3, MG8V3, MGDV3
Purple | 64 GB | MJNL3, MJQ23, MJNY3, MJNT3, MJQ83, MJQF3, MJQ53, MJQC3
128 GB | MJQ93, MJNN3, MJQ33, MJQ03, MJNW3, MJQG3, MJQ63, MJQD3
256 GB | MJNR3, MJQ43, MJQ13, MJNX3, MJQA3, MJQH3, MJQ73, MJQE3
iPhone 12 | A2172 A2402 A2404 A2403 | Bootrom 5281.0.0.100.45 | BCG-E3542A | D53gAP | iPhone13,2 | White | 64 GB | MGGN3, MGJ63, MGEG3, MGG63, MGFM3, MGF53, MGH73, MGHP3
128 GB | MGGV3, MGJC3, MGHD3, MGET3, MGGC3, MGFT3, MGFA3, MGHV3
256 GB | MGH23, MGJH3, MGF03, MGGH3, MGG13, MGFG3, MGHJ3, MGJ13
Black | 64 GB | MGGM3, MGJ53, MGEF3, MGG53, MGFL3, MGF43, MGH63, MGHN3
128 GB | MGGU3, MGJA3, MGHC3, MGER3, MGGA3, MGFR3, MGF93, MGHU3
256 GB | MGH13, MGJG3, MGHH3, MGEX3, MGGG3, MGG03, MGFF3, MGJ03
PRODUCT(RED) | 64 GB | MGGP3, MGJ73, MGEH3, MGG73, MGFN3, MGF63, MGH83, MGHQ3
128 GB | MGGW3, MGJD3, MGHE3, MGEU3, MGGD3, MGFW3, MGFC3, MGHW3
256 GB | MGH33, MGJJ3, MGF13, MGGJ3, MGG23, MGFH3, MGHK3, MGJ23
Green | 64 GB | MGGT3, MGJ93, MGEQ3, MGG93, MGFQ3, MGF83, MGHA3, MGHT3
128 GB | MGGY3, MGJF3, MGHG3, MGEW3, MGGF3, MGFY3, MGFE3, MGHY3
256 GB | MGH53, MGJL3, MGHM3, MGF33, MGGL3, MGG43, MGFK3, MGJ43
Blue | 64 GB | MGGQ3, MGJ83, MGH93, MGEK3, MGG83, MGFP3, MGF73, MGHR3
128 GB | MGGX3, MGJE3, MGEV3, MGGE3, MGFX3, MGFD3, MGHF3, MGHX3
256 GB | MGH43, MGJK3, MGF23, MGGK3, MGG33, MGFJ3, MGHL3, MGJ33
Purple | 64 GB | MJMX3, MJN73, MJN43, MJN13, MJNE3, MJNM3, MJNA3, MJNH3
128 GB | MJNF3, MJMY3, MJN83, MJN53, MJN23, MJNP3, MJNC3, MJNJ3
256 GB | MJN03, MJN93, MJN63, MJN33, MJNG3, MJNQ3, MJND3, MJNK3
iPhone 12 Pro | A2341 A2406 A2407 A2408 | Bootrom 5281.0.0.100.45 | BCG-E3545A | D53pAP | iPhone13,3 | Silver | 128 GB | MGLA3, MGML3, MGJN3, MGKW3, MGKH3, MGK23, MGLP3, MGM63
256 GB | MGLF3, MGMQ3, MGLU3, MGJT3, MGL23, MGKM3, MGK63, MGMA3
512 GB | MGLK3, MGMV3, MGJX3, MGL63, MGKR3, MGKC3, MGLY3, MGMG3
Graphite | 128 GB | MGL93, MGMK3, MGJM3, MGKV3, MGKG3, MGK13, MGLN3, MGM53
256 GB | MGLE3, MGMP3, MGLT3, MGJR3, MGKL3, MGK53, MGL03, MGM93
512 GB | MGLJ3, MGMU3, MGLX3, MGJW3, MGL53, MGKQ3, MGKA3, MGMF3
Gold | 128 GB | MGLC3, MGMM3, MGJP3, MGKX3, MGKJ3, MGK33, MGLQ3, MGM73
256 GB | MGLG3, MGMR3, MGJU3, MGL33, MGKN3, MGK73, MGLV3, MGMC3
512 GB | MGLL3, MGMW3, MGM23, MGJY3, MGL73, MGKT3, MGKE3, MGMH3
Pacific Blue | 128 GB | MGLD3, MGMN3, MGJQ3, MGKY3, MGKK3, MGK43, MGLR3, MGM83
256 GB | MGLH3, MGMT3, MGJV3, MGL43, MGKP3, MGK93, MGLW3, MGMD3
512 GB | MGLM3, MGMX3, MGK03, MGL83, MGKU3, MGKF3, MGM43, MGMJ3
iPhone 12 Pro Max | A2342 A2410 A2411 A2412 | Bootrom 5281.0.0.100.45 | BCG-E3548A | D54pAP | iPhone13,4 | Silver | 128 GB | MGC13, MGD83, MG8Y3, MGA93, MG9Q3, MG9C3, MGCG3, MGCV3
256 GB | MGC53, MGDD3, MGCL3, MG933, MGAJ3, MG9V3, MG9G3, MGD03
512 GB | MGCA3, MGDH3, MG973, MGAU3, MGA23, MG9L3, MGCQ3, MGD43
Graphite | 128 GB | MGC03, MGD73, MG8X3, MGA73, MG9P3, MG9A3, MGCF3, MGCU3
256 GB | MGC43, MGDC3, MGCK3, MG923, MGAH3, MG9U3, MG9F3, MGCY3
512 GB | MGC93, MGDG3, MGCP3, MG963, MGAR3, MG9Y3, MG9K3, MGD33
Gold | 128 GB | MGC23, MGD93, MG903, MGAA3, MG9R3, MG9D3, MGCH3, MGCW3
256 GB | MGC63, MGDE3, MG943, MGAM3, MG9W3, MG9H3, MGCM3, MGD13
512 GB | MGCC3, MGDK3, MGCR3, MG983, MGAW3, MGA33, MG9M3, MGD53
Pacific Blue | 128 GB | MGC33, MGDA3, MGCJ3, MG913, MGAF3, MG9T3, MG9E3, MGCX3
256 GB | MGC73, MGDF3, MG953, MGAQ3, MG9X3, MG9J3, MGCN3, MGD23
512 GB | MGCE3, MGDL3, MG993, MGAX3, MGA43, MG9N3, MGCT3, MGD63
iPhone 13 mini | A2481 A2626 A2629 A2630 A2628 | Bootrom 6338.0.0.200.19 | ? | D16AP | iPhone14,4 | PRODUCT(RED) | 128 GB | MLK33, MLHQ3, MLDF3, MLJG3
256 GB | MLK83, MLHW3, MLDL3, MLJM3
512 GB | MLKE3, MLJ23, MLDR3, MLJW3
Starlight | 128 GB | MLK13, MLHN3, MLDD3, MLJE3
256 GB | MLK63, MLHU3, MLDJ3, MLJK3
512 GB | MLKC3, MLJ03, MLDP3, MLJR3
Midnight | 128 GB | MLK03, MLHM3, MLDC3, MLJC3
256 GB | MLK53, MLHT3, MLDH3, MLJJ3
512 GB | MLKA3, MLHY3, MLDN3, MLJP3
Blue | 128 GB | MLK43, MLHR3, MLDG3, MLJH3
256 GB | MLK93, MLHX3, MLDM3, MLJN3
512 GB | MLKF3, MLJ33, MLDT3, MLJY3
Pink | 128 GB | MLK23, MLHP3, MLDE3, MLJF3
256 GB | MLK73, MLHV3, MLDK3, MLJL3
512 GB | MLKD3, MLJ13, MLDQ3, MLJU3
Green | 128 GB | MNF83, MNF53, MNFF3, MNFC3
256 GB | MNF93, MNF63, MNFG3, MNFD3
512 GB | MNFA3, MNF73, MNFH3, MNFE3
iPhone 13 | A2482 A2631 A2634 A2635 A2633 | Bootrom 6338.0.0.200.19 | ? | D17AP | iPhone14,5 | PRODUCT(RED) | 128 GB | MLPJ3, MLMQ3, MLDX3, MLNF3
256 GB | MLQ93, MLN03, MLE33, MLNL3
512 GB | MLQF3, MLN53, MLEA3, MLNR3
Starlight | 128 GB | MLPG3, MLMM3, MLDV3, MLND3
256 GB | MLQ73, MLMX3, MLE13, MLNJ3
512 GB | MLQD3, MLN33, MLE73, MLNP3
Midnight | 128 GB | MLPF3, MLML3, MLDU3, MLNC3
256 GB | MLQ63, MLN23, MLE03, MLNH3
512 GB | MLQC3, MLN23, MLE63, MLNN3
Blue | 128 GB | MLPK3, MLMT3, MLDY3, MLNG3
256 GB | MLQA3, MLN13, MLE43, MLNM3
512 GB | MLQG3, MLN83, MLEC3, MLNT3
Pink | 128 GB | MLPH3, MLMN3, MLDW3, MLNE3
256 GB | MLQ83, MLMY3, MLE23, MLNK3
512 GB | MLQE3, MLN43, MLE93, MLNQ3
Green | 128 GB | MNGD3, MNG93, MNGK3, MNGG3
256 GB | MNGE3, MNGA3, MNGL3, MNGH3
512 GB | MNGF3, MNGC3, MNGM3, MNGJ3
iPhone 13 Pro | A2483 A2636 A2639 A2640 A2638 | Bootrom 6338.0.0.200.19 | ? | D63AP | iPhone14,2 | Graphite | 128 GB | MLV93, MLTP3, MLT53
256 GB | MLVE3, MLTW3, MLT93
512 GB | MLVH3, MLU13, MLTF3
1TB | MLVV3, MLU93, MLTK3
Gold | 128 GB | MLVC3, MLTR3, MLT73
256 GB | MLVK3, MLTY3, MLTH3
512 GB | MLVQ3, MLU43, MLTH3
1TB | MLVY3, MLUC3, MLTM3
Silver | 128 GB | MLVA3, MLTQ3, MLT63
256 GB | MLVF3, MLTX3, MLTC3
512 GB | MLVN3, MLU33, MLTG3
1TB | MLVW3, MLUA3, MLTL3
Sierra Blue | 128 GB | MLVD3, MLTT3, MLT83
256 GB | MLVP3, MLU03, MLTE3
512 GB | MLVU3, MLU73, MLTJ3
1TB | MLW03, MLUD3, MLTN3
Alpine Green | 128 GB | MNDT3, MNDN3, MNE23
256 GB | MNDU3, MNDP3, MNE33
512 GB | MNDV3, MNDQ3, MNE43
1 TB | MNDW3, MNDR3, MNE53
iPhone 13 Pro Max | A2484 A2641 A2644 A2645 A2643 | Bootrom 6338.0.0.200.19 | BCG-E4003A | D64AP | iPhone14,3 | Graphite | 128 GB | MLL63, MLKL3, MLH43
256 GB | MLLA3, MLKR3, MLH83
512 GB | MLLF3, MLKW3, MLHD3
1TB | MLLK3, MLL23, MLHH3
Gold | 128 GB | MLL83, MLKN3, MLH63
256 GB | MLLD3, MLKU3, MLHA3
512 GB | MLLH3, MLKY3, MLHF3
1TB | MLLM3, MLL43, MLHK3
Silver | 128 GB | MLL73, MLKM3, MLH53
256 GB | MLLC3, MLKT3, MLH93
512 GB | MLLG3, MLKX3, MLHE3
1TB | MLLL3, MLL33, MLHJ3
Sierra Blue | 128 GB | MLL93, MLKP3, MLH73
256 GB | MLLE3, MLKV3, MLHC3
512 GB | MLLJ3, MLL03, MLHG3
1TB | MLLN3, MLL53, MLHL3
Alpine Green | 128 GB | MNCP3, MNCK3, MNCY3
256 GB | MNCQ3, MNCL3, MND03
512 GB | MNCR3, MNCM3, MND13
1 TB | MNCT3, MNCN3, MND23
iPhone SE (3rd generation) | A2595 A2782 A2783 A2784 A2785 | Bootrom 6338.0.0.200.19 | BCG-E4082A BCG-E8064A BCG-E4083A BCG-E8076A | D49AP | iPhone14,6 | Midnight | 64 GB | MMX53, MMWV3, MMXF3, MMYC3
128 GB | MMX83, MMWY3, MMXJ3, MMYF3
256 GB | MMXC3, MMX23, MMXM3, MMYJ3
Starlight | 64 GB | MMX63, MMWW3, MMXG3, MMYD3
128 GB | MMX93, MMX03, MMXK3, MMYG3
256 GB | MMXD3, MMX33, MMXN3, MMYK3
PRODUCT(RED) | 64 GB | MMX73, MMWX3, MMXH3, MMYE3
128 GB | MMXA3, MMX13, MMXL3, MMYH3
256 GB | MMXE3, MMX43, MMXP3, MMYL3
iPhone 14 | A2649 A2881 A2882 A2883 A2884 | ? | ? | D27AP | iPhone14,7 | Blue | 128 GB | MPVN3, MPVH3, MPVG3, MPVJ3
256 GB | MPWP3, MPWM3, MPWL3, MPWN3
512 GB | MPXN3, MPXL3, MPXK3, MPXM3
Midnight | 128 GB | MPUF3, MPUA3, MPU93, MPUD3V
256 GB | MPVX3, MPVV3, MPVU3, MPVW3
512 GB | MPWW3, MPWU3, MPWT3, MPWV3
Starlight | 128 GB | MPUR3, MPUN3, MPUJ3, MPUQ3
256 GB | MPW43, MPW23, MPW13, MPW33
512 GB | MPX33, MPX13, MPX03, MPX23
PRODUCT(RED) | 128 GB | MPVA3, MPV73, MPV63, MPV93
256 GB | MPWH3, MPWF3, MPWE3, MPWG3
512 GB | MPXG3, MPXE3, MPXD3, MPXF3
Purple | 128 GB | MPV03, MPUX3, MPUW3, MPUY3
256 GB | MPWA3, MPW83, MPW73, MPW93
512 GB | MPX93, MPX73, MPX63, MPX83
iPhone 14 Plus | A2632 A2885 A2886 A2887 A2888 | ? | ? | D28AP | iPhone14,8 | Blue | 128 GB | MQ523, MQ3W3, MQ3A3, MQ4H3
256 GB | MQ583, MQ423, MQ3G3, MQ4Q3
512 GB | MQ5G3, MQ493, MQ3Q3, MQ4W3
Midnight | 128 GB | MQ4X3, MQ3R3, MQ353, MQ4A3
256 GB | MQ533, MQ3X3, MQ3C3, MQ4J3
512 GB | MQ593, MQ433, MQ3H3, MQ4R3
Starlight | 128 GB | MQ4Y3, MQ3T3, MQ363, MQ4D3
256 GB | MQ553, MQ3Y3, MQ3D3, MQ4L3
512 GB | MQ5D3, MQ443, MQ3J3, MQ4T3
PRODUCT(RED) | 128 GB | MQ513, MQ3V3, MQ393, MQ4F3
256 GB | MQ573, MQ413, MQ3F3, MQ4P3
512 GB | MQ5F3, MQ473, MQ3P3, MQ4V3
Purple | 128 GB | MQ503, MQ3U3, MQ373, MQ4E3
256 GB | MQ563, MQ403, MQ3E3, MQ4M3V
512 GB | MQ5E3, MQ463, MQ3K3, MQ4U3
iPhone 14 Pro | A2650 A2889 A2890 A2891 A2892 | Bootrom 7195.0.0.300.25 | BCG-E8140A BCG-E8151A | D73AP | iPhone15,2 | Deep Purple | 128 GB | MQ0E3, MQ0G3, MQ0D3, MQ0F3
256 GB | MQ1D3, MQ1F3, MQ1C3, MQ1E3
512 GB | MQ273, MQ293, MQ263, MQ283
1 TB | MQ303, MQ323, MQ2Y3, MQ313
Gold | 128 GB | MQ063, MQ083, MQ053, MQ073
256 GB | MQ163, MQ183, MQ143, MQ173
512 GB | MQ213, MQ233, MQ203, MQ223
1 TB | MQ2T3, MQ2V3, MQ2R3, MQ2U3
Silver | 128 GB | MQ003, MQ023, MPXY3, MQ013
256 GB | MQ0X3, MQ103, MQ0W3, MQ0Y3
512 GB | MQ1U3, MQ1W3, MQ1R3, MQ1V3
1 TB | MQ2L3, MQ2N3, MQ2K3, MQ2M3
Space Black | 128 GB | MPXT3, MPXV3, MPXR3, MPXU3
256 GB | MQ0N3, MQ0T3, MQ0M3, MQ0Q3
512 GB | MQ1K3, MQ1M3, MQ1J3, MQ1L3
1 TB | MQ2E3, MQ2G3, MQ2D3, MQ2F3
iPhone 14 Pro Max | A2651 A2893 A2894 A2895 A2896 | Bootrom 7195.0.0.300.25 | ? | D74AP | iPhone15,3 | Deep Purple | 128 GB | MQ9T3, MQ8R3, MQ863, MQ993
256 GB | MQ9X3, MQ8W3, MQ8A3, MQ9E3
512 GB | MQAM3, MQ913, MQ8G3, MQ9J3
1 TB | MQC53, MQ953, MQ8M3, MQ9N3
Gold | 128 GB | MQ9R3, MQ8Q3, MQ853, MQ983
256 GB | MQ9W3, MQ8V3, MQ893, MQ9D3
512 GB | MQAJ3, MQ903, MQ8F3, MQ9H3
1 TB | MQC43, MQ943, MQ8L3, MQ9M3
Silver | 128 GB | MQ9Q3, MQ8P3, MQ843, MQ973
256 GB | MQ9V3, MQ8U3, MQ883, MQ9C3
512 GB | MQAH3, MQ8Y3, MQ8E3, MQ9G3
1 TB | MQC33, MQ933, MQ8J3, MQ9L3
Space Black | 128 GB | MQ9P3, MQ8N3, MQ833, MQ963
256 GB | MQ9U3, MQ8T3, MQ873, MQ9A3
512 GB | MQAF3, MQ8X3, MQ8D3, MQ9F3
1 TB | MQC23, MQ923, MQ8H3, MQ9K3

## iPod touch

Generation | "A" Number | Bootrom | FCC ID | Internal Name | Identifier | Color | Storage | Model
--- | --- | --- | --- | --- | --- | --- | --- | ---
iPod touch | A1213 | Bootrom Rev.2 | BCGA1213 | N45AP | iPod1,1 | Black | 8 GB | MA623, MA624, MA839
16 GB | MA627, MA628
32 GB | MB376
iPod touch (2nd generation) | A1288 A1319[1] | Bootrom 240.4 | BCGA1288 | N72AP | iPod2,1 | Black | 8 GB | MB525, MB528, MB529
16 GB | MB531, MB532
32 GB | MB533, MB534
Bootrom 240.5.1 | 8 GB | MC086
iPod touch (3rd generation) | A1318 | Bootrom 359.5 | BCG-2310 | N18AP | iPod3,1 | Black | 32 GB | MC008
64 GB | MC011
iPod touch (4th generation) | A1367 | Bootrom 574.4 | BCG-E2407 | N81AP | iPod4,1 | Black | 8 GB | MC540
16 GB | ME178
32 GB | MC544
64 GB | MC547
White | 8 GB | MD057
16 GB | ME179
32 GB | MD058
64 GB | MD059
iPod touch (5th generation) | A1421 | ROM | BCG-A1421 | N78AP | iPod5,1 | Black & Slate | 32 GB | MD723
64 GB | MD724
Blue | 16 GB | MGG32
32 GB | MD717
64 GB | MD718
Pink | 16 GB | MGFY2
32 GB | MC903
64 GB | MC904
PRODUCT(RED) | 16 GB | MGG72
32 GB | MD749
64 GB | MD750
White & Silver | 16 GB | MGG52
32 GB | MD720, ME108[6]
64 GB | MD721
Space Gray | 16 GB | MGG82
32 GB | ME978
64 GB | ME979
Yellow | 16 GB | MGG12
32 GB | MD714
64 GB | MD715
A1509 | N78aAP | Black & Silver | 16 GB | ME643
iPod touch (6th generation) | A1574 | Bootrom 1992.0.0.1.19 | BCGA1574 | N102AP | iPod7,1 | Blue | 16 GB | MKH22
32 GB | MKHV2
64 GB | MKHE2
128 GB | MKWP2
Gold | 16 GB | MKH02
32 GB | MKHT2
64 GB | MKHC2
128 GB | MKWM2
Pink | 16 GB | MKGX2
32 GB | MKHQ2
64 GB | MKGW2
128 GB | MKWK2
PRODUCT(RED) | 16 GB | MKH82
32 GB | MKJ22
64 GB | MKHN2
128 GB | MKWW2
Silver | 16 GB | MKH42
32 GB | MKHX2
64 GB | MKHJ2
128 GB | MKWR2
Space Gray | 16 GB | MKH62
32 GB | MKJ02
64 GB | MKHL2
128 GB | MKWU2
iPod touch (7th generation) | A2178 | Bootrom 2696.0.0.1.33 | BCGA2178 | N112AP | iPod9,1 | Blue | 32 GB | MVHU2
128 GB | MVJ32
256 GB | MVJC2
Gold | 32 GB | MVHT2
128 GB | MVJ22
256 GB | MVJ92
Pink | 32 GB | MVHR2
128 GB | MVHY2
256 GB | MVJ82
PRODUCT(RED) | 32 GB | MVHX2
128 GB | MVJ72
256 GB | MVJF2
Silver | 32 GB | MVHV2
128 GB | MVJ52
256 GB | MVJD2
Space Gray | 32 GB | MVHW2
128 GB | MVJ62
256 GB | MVJE2

## Mac

### iMac

Generation | "A" Number | FCC ID | Internal Name | Identifier | Color | Storage | Model
--- | --- | --- | --- | --- | --- | --- | ---
iMac (24-inch, M1, 2021) | A2438 | BCGA2438 | J456AP | iMac21,1 | Silver | 256 GB | MGTF3
Pink | 256 GB | MJVA3
Blue | 256 GB | MJV93
Green | 256 GB | MJV83
A2439 | BCGA2439 | J457AP | iMac21,2 | Silver | 256 GB | MGPC3
512GB | MGPD3
Pink | 256 GB | MGPM3
512GB | MGPN3
Blue | 256 GB | MGPK3
512GB | MGPL3
Green | 256 GB | MGPH3
512GB | MGPJ3
Yellow | 256 GB | ?
512GB | ?
Orange | 256 GB | ?
512GB | ?
Purple | 256 GB | ?
512GB | ?

### Mac mini

Generation | "A" Number | FCC ID | Internal Name | Identifier | Color | Storage | Model
--- | --- | --- | --- | --- | --- | --- | ---
Mac mini (M1, 2020) | A2348 | BCGA2348 | J274AP | Macmini9,1 | Silver | 256 GB | MGNR3
512 GB | MGNT3

### MacBook Air

Generation | "A" Number | FCC ID | Internal Name | Identifier | Color | Storage | Model
--- | --- | --- | --- | --- | --- | --- | ---
MacBook Air (Late 2020) | A2337 | BCGA2337 | J313AP | MacBookAir10,1 | Space Gray | 256 GB | MGN63
512 GB | MGN73
Silver | 256 GB | MGN93
512 GB | MGNA3
Gold | 256 GB | MGND3
512 GB | MGNE3

### MacBook Pro

Generation | "A" Number | FCC ID | Internal Name | Identifier | Color | Storage | Model
--- | --- | --- | --- | --- | --- | --- | ---
MacBook Pro (13-inch, M1, 2020) | A2338 | BCGA2338 | J293AP | MacBookPro17,1 | Space Gray | 256 GB | MYD82
512 GB | MYD92
Silver | 256 GB | MYDA2
512 GB | MYDC2
MacBook Pro (14-inch, 2021) | ? | ? | J314sAP | MacBookPro18,3 | Space Gray | 512 GB | MKGP3
1 TB | MKGQ3
Silver | 512 GB | MKGR3
1 TB | MKGT3
? | ? | J314cAP | MacBookPro18,4 | Space Gray | 512 GB | ?
1 TB | ?
Silver | 512 GB | ?
1 TB | ?
MacBook Pro (16-inch, 2021) | ? | ? | J316sAP | MacBookPro18,1 | Space Gray | 512 GB | MK183
1 TB | MK193
Silver | 512 GB | MK1E3
1 TB | MK1F3
? | ? | J316cAP | MacBookPro18,2 | Space Gray | 1 TB | MK1A3
Silver | 1 TB | MK1H3

### Mac Studio

Generation | "A" Number | FCC ID | Internal Name | Identifier | Color | Storage | Model
--- | --- | --- | --- | --- | --- | --- | ---
Mac Studio (M1 Max, 2022) | ? | ? | ? | ? | Silver | N/A | MJMV3
Mac Studio (M1 Ultra, 2022) | ? | ? | ? | ? | Silver | N/A | MJMW3

## See Also

- List of AirPods
- List of Apple TVs
- List of Siri Remotes
- List of Apple Watches
- List of HomePods
- List of iPads
- List of Apple Pencils
- List of Smart Keyboards
- List of iPad minis
- List of iPhones
- List of iPod touches
- Model Regions

## Notes

1. ^ a b c d e f g h i j k l m n o p q r China-exclusive model.
2. ^ a b Marketed as "iPhone 6 (2017)", this is a "limited edition" that was sold by carriers and resellers in a handful of countries.
3. ^ a b Japan-exclusive iPhone 7 model containing FeliCa for payment and transit with Apple Pay.
4. ^ a b c d e f Japan-exclusive model.
5. ^ a b c d e China-exclusive model containing support for two nano-SIM cards.
6. ^ a b c Demo model.
7. ^ China-exclusive model support for two nano-SIM cards model selling by carriers (China Mobile only) and resellers in China.

Retrieved from "https://www.theiphonewiki.com/w/index.php?title=Models&oldid=126060"